import typing

import typing_extensions

_list = list

@typing.type_check_only
class Addressable(typing_extensions.TypedDict, total=False):
    url: str

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class AuthorizedDomain(typing_extensions.TypedDict, total=False):
    id: str
    name: str

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class CancelExecutionRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ConfigMapEnvSource(typing_extensions.TypedDict, total=False):
    localObjectReference: LocalObjectReference
    name: str
    optional: bool

@typing.type_check_only
class ConfigMapKeySelector(typing_extensions.TypedDict, total=False):
    key: str
    localObjectReference: LocalObjectReference
    name: str
    optional: bool

@typing.type_check_only
class ConfigMapVolumeSource(typing_extensions.TypedDict, total=False):
    defaultMode: int
    items: _list[KeyToPath]
    name: str
    optional: bool

@typing.type_check_only
class Configuration(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str
    metadata: ObjectMeta
    spec: ConfigurationSpec
    status: ConfigurationStatus

@typing.type_check_only
class ConfigurationSpec(typing_extensions.TypedDict, total=False):
    template: RevisionTemplate

@typing.type_check_only
class ConfigurationStatus(typing_extensions.TypedDict, total=False):
    conditions: _list[GoogleCloudRunV1Condition]
    latestCreatedRevisionName: str
    latestReadyRevisionName: str
    observedGeneration: int

@typing.type_check_only
class Container(typing_extensions.TypedDict, total=False):
    args: _list[str]
    command: _list[str]
    env: _list[EnvVar]
    envFrom: _list[EnvFromSource]
    image: str
    imagePullPolicy: str
    livenessProbe: Probe
    name: str
    ports: _list[ContainerPort]
    readinessProbe: Probe
    resources: ResourceRequirements
    securityContext: SecurityContext
    startupProbe: Probe
    terminationMessagePath: str
    terminationMessagePolicy: str
    volumeMounts: _list[VolumeMount]
    workingDir: str

@typing.type_check_only
class ContainerPort(typing_extensions.TypedDict, total=False):
    containerPort: int
    name: str
    protocol: str

@typing.type_check_only
class DomainMapping(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str
    metadata: ObjectMeta
    spec: DomainMappingSpec
    status: DomainMappingStatus

@typing.type_check_only
class DomainMappingSpec(typing_extensions.TypedDict, total=False):
    certificateMode: typing_extensions.Literal[
        "CERTIFICATE_MODE_UNSPECIFIED", "NONE", "AUTOMATIC"
    ]
    forceOverride: bool
    routeName: str

@typing.type_check_only
class DomainMappingStatus(typing_extensions.TypedDict, total=False):
    conditions: _list[GoogleCloudRunV1Condition]
    mappedRouteName: str
    observedGeneration: int
    resourceRecords: _list[ResourceRecord]
    url: str

@typing.type_check_only
class EnvFromSource(typing_extensions.TypedDict, total=False):
    configMapRef: ConfigMapEnvSource
    prefix: str
    secretRef: SecretEnvSource

@typing.type_check_only
class EnvVar(typing_extensions.TypedDict, total=False):
    name: str
    value: str
    valueFrom: EnvVarSource

@typing.type_check_only
class EnvVarSource(typing_extensions.TypedDict, total=False):
    configMapKeyRef: ConfigMapKeySelector
    secretKeyRef: SecretKeySelector

@typing.type_check_only
class ExecAction(typing_extensions.TypedDict, total=False):
    command: _list[str]

@typing.type_check_only
class Execution(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str
    metadata: ObjectMeta
    spec: ExecutionSpec
    status: ExecutionStatus

@typing.type_check_only
class ExecutionReference(typing_extensions.TypedDict, total=False):
    completionTimestamp: str
    creationTimestamp: str
    name: str

@typing.type_check_only
class ExecutionSpec(typing_extensions.TypedDict, total=False):
    parallelism: int
    taskCount: int
    template: TaskTemplateSpec

@typing.type_check_only
class ExecutionStatus(typing_extensions.TypedDict, total=False):
    cancelledCount: int
    completionTime: str
    conditions: _list[GoogleCloudRunV1Condition]
    failedCount: int
    logUri: str
    observedGeneration: int
    retriedCount: int
    runningCount: int
    startTime: str
    succeededCount: int

@typing.type_check_only
class ExecutionTemplateSpec(typing_extensions.TypedDict, total=False):
    metadata: ObjectMeta
    spec: ExecutionSpec

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class GRPCAction(typing_extensions.TypedDict, total=False):
    port: int
    service: str

@typing.type_check_only
class GoogleCloudRunV1Condition(typing_extensions.TypedDict, total=False):
    lastTransitionTime: str
    message: str
    reason: str
    severity: str
    status: str
    type: str

@typing.type_check_only
class GoogleRpcStatus(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class HTTPGetAction(typing_extensions.TypedDict, total=False):
    host: str
    httpHeaders: _list[HTTPHeader]
    path: str
    scheme: str

@typing.type_check_only
class HTTPHeader(typing_extensions.TypedDict, total=False):
    name: str
    value: str

@typing.type_check_only
class Job(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str
    metadata: ObjectMeta
    spec: JobSpec
    status: JobStatus

@typing.type_check_only
class JobSpec(typing_extensions.TypedDict, total=False):
    template: ExecutionTemplateSpec

@typing.type_check_only
class JobStatus(typing_extensions.TypedDict, total=False):
    conditions: _list[GoogleCloudRunV1Condition]
    executionCount: int
    latestCreatedExecution: ExecutionReference
    observedGeneration: int

@typing.type_check_only
class KeyToPath(typing_extensions.TypedDict, total=False):
    key: str
    mode: int
    path: str

@typing.type_check_only
class ListAuthorizedDomainsResponse(typing_extensions.TypedDict, total=False):
    domains: _list[AuthorizedDomain]
    nextPageToken: str

@typing.type_check_only
class ListConfigurationsResponse(typing_extensions.TypedDict, total=False):
    apiVersion: str
    items: _list[Configuration]
    kind: str
    metadata: ListMeta
    unreachable: _list[str]

@typing.type_check_only
class ListDomainMappingsResponse(typing_extensions.TypedDict, total=False):
    apiVersion: str
    items: _list[DomainMapping]
    kind: str
    metadata: ListMeta
    unreachable: _list[str]

@typing.type_check_only
class ListExecutionsResponse(typing_extensions.TypedDict, total=False):
    apiVersion: str
    items: _list[Execution]
    kind: str
    metadata: ListMeta
    unreachable: _list[str]

@typing.type_check_only
class ListJobsResponse(typing_extensions.TypedDict, total=False):
    apiVersion: str
    items: _list[Job]
    kind: str
    metadata: ListMeta
    unreachable: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

AlternativeListMeta = typing_extensions.TypedDict(
    "AlternativeListMeta",
    {
        "continue": str,
        "resourceVersion": str,
        "selfLink": str,
    },
    total=False,
)

@typing.type_check_only
class ListMeta(AlternativeListMeta): ...

@typing.type_check_only
class ListRevisionsResponse(typing_extensions.TypedDict, total=False):
    apiVersion: str
    items: _list[Revision]
    kind: str
    metadata: ListMeta
    unreachable: _list[str]

@typing.type_check_only
class ListRoutesResponse(typing_extensions.TypedDict, total=False):
    apiVersion: str
    items: _list[Route]
    kind: str
    metadata: ListMeta
    unreachable: _list[str]

@typing.type_check_only
class ListServicesResponse(typing_extensions.TypedDict, total=False):
    apiVersion: str
    items: _list[Service]
    kind: str
    metadata: ListMeta
    unreachable: _list[str]

@typing.type_check_only
class ListTasksResponse(typing_extensions.TypedDict, total=False):
    apiVersion: str
    items: _list[Task]
    kind: str
    metadata: ListMeta
    unreachable: _list[str]

@typing.type_check_only
class LocalObjectReference(typing_extensions.TypedDict, total=False):
    name: str

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class ObjectMeta(typing_extensions.TypedDict, total=False):
    annotations: dict[str, typing.Any]
    clusterName: str
    creationTimestamp: str
    deletionGracePeriodSeconds: int
    deletionTimestamp: str
    finalizers: _list[str]
    generateName: str
    generation: int
    labels: dict[str, typing.Any]
    name: str
    namespace: str
    ownerReferences: _list[OwnerReference]
    resourceVersion: str
    selfLink: str
    uid: str

@typing.type_check_only
class OwnerReference(typing_extensions.TypedDict, total=False):
    apiVersion: str
    blockOwnerDeletion: bool
    controller: bool
    kind: str
    name: str
    uid: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class Probe(typing_extensions.TypedDict, total=False):
    exec: ExecAction
    failureThreshold: int
    grpc: GRPCAction
    httpGet: HTTPGetAction
    initialDelaySeconds: int
    periodSeconds: int
    successThreshold: int
    tcpSocket: TCPSocketAction
    timeoutSeconds: int

@typing.type_check_only
class ResourceRecord(typing_extensions.TypedDict, total=False):
    name: str
    rrdata: str
    type: typing_extensions.Literal["RECORD_TYPE_UNSPECIFIED", "A", "AAAA", "CNAME"]

@typing.type_check_only
class ResourceRequirements(typing_extensions.TypedDict, total=False):
    limits: dict[str, typing.Any]
    requests: dict[str, typing.Any]

@typing.type_check_only
class Revision(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str
    metadata: ObjectMeta
    spec: RevisionSpec
    status: RevisionStatus

@typing.type_check_only
class RevisionSpec(typing_extensions.TypedDict, total=False):
    containerConcurrency: int
    containers: _list[Container]
    enableServiceLinks: bool
    imagePullSecrets: _list[LocalObjectReference]
    serviceAccountName: str
    timeoutSeconds: int
    volumes: _list[Volume]

@typing.type_check_only
class RevisionStatus(typing_extensions.TypedDict, total=False):
    conditions: _list[GoogleCloudRunV1Condition]
    imageDigest: str
    logUrl: str
    observedGeneration: int
    serviceName: str

@typing.type_check_only
class RevisionTemplate(typing_extensions.TypedDict, total=False):
    metadata: ObjectMeta
    spec: RevisionSpec

@typing.type_check_only
class Route(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str
    metadata: ObjectMeta
    spec: RouteSpec
    status: RouteStatus

@typing.type_check_only
class RouteSpec(typing_extensions.TypedDict, total=False):
    traffic: _list[TrafficTarget]

@typing.type_check_only
class RouteStatus(typing_extensions.TypedDict, total=False):
    address: Addressable
    conditions: _list[GoogleCloudRunV1Condition]
    observedGeneration: int
    traffic: _list[TrafficTarget]
    url: str

@typing.type_check_only
class RunJobRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class SecretEnvSource(typing_extensions.TypedDict, total=False):
    localObjectReference: LocalObjectReference
    name: str
    optional: bool

@typing.type_check_only
class SecretKeySelector(typing_extensions.TypedDict, total=False):
    key: str
    localObjectReference: LocalObjectReference
    name: str
    optional: bool

@typing.type_check_only
class SecretVolumeSource(typing_extensions.TypedDict, total=False):
    defaultMode: int
    items: _list[KeyToPath]
    optional: bool
    secretName: str

@typing.type_check_only
class SecurityContext(typing_extensions.TypedDict, total=False):
    runAsUser: int

@typing.type_check_only
class Service(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str
    metadata: ObjectMeta
    spec: ServiceSpec
    status: ServiceStatus

@typing.type_check_only
class ServiceSpec(typing_extensions.TypedDict, total=False):
    template: RevisionTemplate
    traffic: _list[TrafficTarget]

@typing.type_check_only
class ServiceStatus(typing_extensions.TypedDict, total=False):
    address: Addressable
    conditions: _list[GoogleCloudRunV1Condition]
    latestCreatedRevisionName: str
    latestReadyRevisionName: str
    observedGeneration: int
    traffic: _list[TrafficTarget]
    url: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: StatusDetails
    message: str
    metadata: ListMeta
    reason: str
    status: str

@typing.type_check_only
class StatusCause(typing_extensions.TypedDict, total=False):
    field: str
    message: str
    reason: str

@typing.type_check_only
class StatusDetails(typing_extensions.TypedDict, total=False):
    causes: _list[StatusCause]
    group: str
    kind: str
    name: str
    retryAfterSeconds: int
    uid: str

@typing.type_check_only
class TCPSocketAction(typing_extensions.TypedDict, total=False):
    host: str
    port: int

@typing.type_check_only
class Task(typing_extensions.TypedDict, total=False):
    apiVersion: str
    kind: str
    metadata: ObjectMeta
    spec: TaskSpec
    status: TaskStatus

@typing.type_check_only
class TaskAttemptResult(typing_extensions.TypedDict, total=False):
    exitCode: int
    status: GoogleRpcStatus

@typing.type_check_only
class TaskSpec(typing_extensions.TypedDict, total=False):
    containers: _list[Container]
    maxRetries: int
    serviceAccountName: str
    timeoutSeconds: str
    volumes: _list[Volume]

@typing.type_check_only
class TaskStatus(typing_extensions.TypedDict, total=False):
    completionTime: str
    conditions: _list[GoogleCloudRunV1Condition]
    index: int
    lastAttemptResult: TaskAttemptResult
    logUri: str
    observedGeneration: int
    retried: int
    startTime: str

@typing.type_check_only
class TaskTemplateSpec(typing_extensions.TypedDict, total=False):
    spec: TaskSpec

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TrafficTarget(typing_extensions.TypedDict, total=False):
    configurationName: str
    latestRevision: bool
    percent: int
    revisionName: str
    tag: str
    url: str

@typing.type_check_only
class Volume(typing_extensions.TypedDict, total=False):
    configMap: ConfigMapVolumeSource
    name: str
    secret: SecretVolumeSource

@typing.type_check_only
class VolumeMount(typing_extensions.TypedDict, total=False):
    mountPath: str
    name: str
    readOnly: bool
    subPath: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AbuseReport(typing_extensions.TypedDict, total=False):
    abuseTypes: _list[AbuseType]
    description: str
    relatedEntities: _list[RelatedEntity]
    subject: Entity

@typing.type_check_only
class AbuseType(typing_extensions.TypedDict, total=False):
    id: str

@typing.type_check_only
class AccessPolicy(typing_extensions.TypedDict, total=False):
    allowed: bool
    exception: _list[str]

@typing.type_check_only
class Activity(typing_extensions.TypedDict, total=False):
    contentDetails: ActivityContentDetails
    etag: str
    id: str
    kind: str
    snippet: ActivitySnippet

@typing.type_check_only
class ActivityContentDetails(typing_extensions.TypedDict, total=False):
    bulletin: ActivityContentDetailsBulletin
    channelItem: ActivityContentDetailsChannelItem
    comment: ActivityContentDetailsComment
    favorite: ActivityContentDetailsFavorite
    like: ActivityContentDetailsLike
    playlistItem: ActivityContentDetailsPlaylistItem
    promotedItem: ActivityContentDetailsPromotedItem
    recommendation: ActivityContentDetailsRecommendation
    social: ActivityContentDetailsSocial
    subscription: ActivityContentDetailsSubscription
    upload: ActivityContentDetailsUpload

@typing.type_check_only
class ActivityContentDetailsBulletin(typing_extensions.TypedDict, total=False):
    resourceId: ResourceId

@typing.type_check_only
class ActivityContentDetailsChannelItem(typing_extensions.TypedDict, total=False):
    resourceId: ResourceId

@typing.type_check_only
class ActivityContentDetailsComment(typing_extensions.TypedDict, total=False):
    resourceId: ResourceId

@typing.type_check_only
class ActivityContentDetailsFavorite(typing_extensions.TypedDict, total=False):
    resourceId: ResourceId

@typing.type_check_only
class ActivityContentDetailsLike(typing_extensions.TypedDict, total=False):
    resourceId: ResourceId

@typing.type_check_only
class ActivityContentDetailsPlaylistItem(typing_extensions.TypedDict, total=False):
    playlistId: str
    playlistItemId: str
    resourceId: ResourceId

@typing.type_check_only
class ActivityContentDetailsPromotedItem(typing_extensions.TypedDict, total=False):
    adTag: str
    clickTrackingUrl: str
    creativeViewUrl: str
    ctaType: typing_extensions.Literal["ctaTypeUnspecified", "visitAdvertiserSite"]
    customCtaButtonText: str
    descriptionText: str
    destinationUrl: str
    forecastingUrl: _list[str]
    impressionUrl: _list[str]
    videoId: str

@typing.type_check_only
class ActivityContentDetailsRecommendation(typing_extensions.TypedDict, total=False):
    reason: typing_extensions.Literal[
        "reasonUnspecified", "videoFavorited", "videoLiked", "videoWatched"
    ]
    resourceId: ResourceId
    seedResourceId: ResourceId

@typing.type_check_only
class ActivityContentDetailsSocial(typing_extensions.TypedDict, total=False):
    author: str
    imageUrl: str
    referenceUrl: str
    resourceId: ResourceId
    type: typing_extensions.Literal["unspecified", "googlePlus", "facebook", "twitter"]

@typing.type_check_only
class ActivityContentDetailsSubscription(typing_extensions.TypedDict, total=False):
    resourceId: ResourceId

@typing.type_check_only
class ActivityContentDetailsUpload(typing_extensions.TypedDict, total=False):
    videoId: str

@typing.type_check_only
class ActivityListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[Activity]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    prevPageToken: str
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class ActivitySnippet(typing_extensions.TypedDict, total=False):
    channelId: str
    channelTitle: str
    description: str
    groupId: str
    publishedAt: str
    thumbnails: ThumbnailDetails
    title: str
    type: typing_extensions.Literal[
        "typeUnspecified",
        "upload",
        "like",
        "favorite",
        "comment",
        "subscription",
        "playlistItem",
        "recommendation",
        "bulletin",
        "social",
        "channelItem",
        "promotedItem",
    ]

@typing.type_check_only
class Caption(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    snippet: CaptionSnippet

@typing.type_check_only
class CaptionListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[Caption]
    kind: str
    visitorId: str

@typing.type_check_only
class CaptionSnippet(typing_extensions.TypedDict, total=False):
    audioTrackType: typing_extensions.Literal[
        "unknown", "primary", "commentary", "descriptive"
    ]
    failureReason: typing_extensions.Literal[
        "unknownFormat", "unsupportedFormat", "processingFailed"
    ]
    isAutoSynced: bool
    isCC: bool
    isDraft: bool
    isEasyReader: bool
    isLarge: bool
    language: str
    lastUpdated: str
    name: str
    status: typing_extensions.Literal["serving", "syncing", "failed"]
    trackKind: typing_extensions.Literal["standard", "ASR", "forced"]
    videoId: str

@typing.type_check_only
class CdnSettings(typing_extensions.TypedDict, total=False):
    format: str
    frameRate: typing_extensions.Literal["30fps", "60fps", "variable"]
    ingestionInfo: IngestionInfo
    ingestionType: typing_extensions.Literal["rtmp", "dash", "webrtc", "hls"]
    resolution: typing_extensions.Literal[
        "240p", "360p", "480p", "720p", "1080p", "1440p", "2160p", "variable"
    ]

@typing.type_check_only
class Channel(typing_extensions.TypedDict, total=False):
    auditDetails: ChannelAuditDetails
    brandingSettings: ChannelBrandingSettings
    contentDetails: ChannelContentDetails
    contentOwnerDetails: ChannelContentOwnerDetails
    conversionPings: ChannelConversionPings
    etag: str
    id: str
    kind: str
    localizations: dict[str, typing.Any]
    snippet: ChannelSnippet
    statistics: ChannelStatistics
    status: ChannelStatus
    topicDetails: ChannelTopicDetails

@typing.type_check_only
class ChannelAuditDetails(typing_extensions.TypedDict, total=False):
    communityGuidelinesGoodStanding: bool
    contentIdClaimsGoodStanding: bool
    copyrightStrikesGoodStanding: bool

@typing.type_check_only
class ChannelBannerResource(typing_extensions.TypedDict, total=False):
    etag: str
    kind: str
    url: str

@typing.type_check_only
class ChannelBrandingSettings(typing_extensions.TypedDict, total=False):
    channel: ChannelSettings
    hints: _list[PropertyValue]
    image: ImageSettings
    watch: WatchSettings

@typing.type_check_only
class ChannelContentDetails(typing_extensions.TypedDict, total=False):
    relatedPlaylists: dict[str, typing.Any]

@typing.type_check_only
class ChannelContentOwnerDetails(typing_extensions.TypedDict, total=False):
    contentOwner: str
    timeLinked: str

@typing.type_check_only
class ChannelConversionPing(typing_extensions.TypedDict, total=False):
    context: typing_extensions.Literal["subscribe", "unsubscribe", "cview"]
    conversionUrl: str

@typing.type_check_only
class ChannelConversionPings(typing_extensions.TypedDict, total=False):
    pings: _list[ChannelConversionPing]

@typing.type_check_only
class ChannelListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[Channel]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    prevPageToken: str
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class ChannelLocalization(typing_extensions.TypedDict, total=False):
    description: str
    title: str

@typing.type_check_only
class ChannelProfileDetails(typing_extensions.TypedDict, total=False):
    channelId: str
    channelUrl: str
    displayName: str
    profileImageUrl: str

@typing.type_check_only
class ChannelSection(typing_extensions.TypedDict, total=False):
    contentDetails: ChannelSectionContentDetails
    etag: str
    id: str
    kind: str
    localizations: dict[str, typing.Any]
    snippet: ChannelSectionSnippet
    targeting: ChannelSectionTargeting

@typing.type_check_only
class ChannelSectionContentDetails(typing_extensions.TypedDict, total=False):
    channels: _list[str]
    playlists: _list[str]

@typing.type_check_only
class ChannelSectionListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[ChannelSection]
    kind: str
    visitorId: str

@typing.type_check_only
class ChannelSectionLocalization(typing_extensions.TypedDict, total=False):
    title: str

@typing.type_check_only
class ChannelSectionSnippet(typing_extensions.TypedDict, total=False):
    channelId: str
    defaultLanguage: str
    localized: ChannelSectionLocalization
    position: int
    style: typing_extensions.Literal[
        "channelsectionStyleUnspecified", "horizontalRow", "verticalList"
    ]
    title: str
    type: typing_extensions.Literal[
        "channelsectionTypeUndefined",
        "singlePlaylist",
        "multiplePlaylists",
        "popularUploads",
        "recentUploads",
        "likes",
        "allPlaylists",
        "likedPlaylists",
        "recentPosts",
        "recentActivity",
        "liveEvents",
        "upcomingEvents",
        "completedEvents",
        "multipleChannels",
        "postedVideos",
        "postedPlaylists",
        "subscriptions",
    ]

@typing.type_check_only
class ChannelSectionTargeting(typing_extensions.TypedDict, total=False):
    countries: _list[str]
    languages: _list[str]
    regions: _list[str]

@typing.type_check_only
class ChannelSettings(typing_extensions.TypedDict, total=False):
    country: str
    defaultLanguage: str
    defaultTab: str
    description: str
    featuredChannelsTitle: str
    featuredChannelsUrls: _list[str]
    keywords: str
    moderateComments: bool
    profileColor: str
    showBrowseView: bool
    showRelatedChannels: bool
    title: str
    trackingAnalyticsAccountId: str
    unsubscribedTrailer: str

@typing.type_check_only
class ChannelSnippet(typing_extensions.TypedDict, total=False):
    country: str
    customUrl: str
    defaultLanguage: str
    description: str
    localized: ChannelLocalization
    publishedAt: str
    thumbnails: ThumbnailDetails
    title: str

@typing.type_check_only
class ChannelStatistics(typing_extensions.TypedDict, total=False):
    commentCount: str
    hiddenSubscriberCount: bool
    subscriberCount: str
    videoCount: str
    viewCount: str

@typing.type_check_only
class ChannelStatus(typing_extensions.TypedDict, total=False):
    isLinked: bool
    longUploadsStatus: typing_extensions.Literal[
        "longUploadsUnspecified", "allowed", "eligible", "disallowed"
    ]
    madeForKids: bool
    privacyStatus: typing_extensions.Literal["public", "unlisted", "private"]
    selfDeclaredMadeForKids: bool

@typing.type_check_only
class ChannelToStoreLinkDetails(typing_extensions.TypedDict, total=False):
    merchantId: str
    storeName: str
    storeUrl: str

@typing.type_check_only
class ChannelTopicDetails(typing_extensions.TypedDict, total=False):
    topicCategories: _list[str]
    topicIds: _list[str]

@typing.type_check_only
class Comment(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    snippet: CommentSnippet

@typing.type_check_only
class CommentListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[Comment]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class CommentSnippet(typing_extensions.TypedDict, total=False):
    authorChannelId: CommentSnippetAuthorChannelId
    authorChannelUrl: str
    authorDisplayName: str
    authorProfileImageUrl: str
    canRate: bool
    channelId: str
    likeCount: int
    moderationStatus: typing_extensions.Literal[
        "published", "heldForReview", "likelySpam", "rejected"
    ]
    parentId: str
    publishedAt: str
    textDisplay: str
    textOriginal: str
    updatedAt: str
    videoId: str
    viewerRating: typing_extensions.Literal["none", "like", "dislike"]

@typing.type_check_only
class CommentSnippetAuthorChannelId(typing_extensions.TypedDict, total=False):
    value: str

@typing.type_check_only
class CommentThread(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    replies: CommentThreadReplies
    snippet: CommentThreadSnippet

@typing.type_check_only
class CommentThreadListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[CommentThread]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class CommentThreadReplies(typing_extensions.TypedDict, total=False):
    comments: _list[Comment]

@typing.type_check_only
class CommentThreadSnippet(typing_extensions.TypedDict, total=False):
    canReply: bool
    channelId: str
    isPublic: bool
    topLevelComment: Comment
    totalReplyCount: int
    videoId: str

@typing.type_check_only
class ContentRating(typing_extensions.TypedDict, total=False):
    acbRating: typing_extensions.Literal[
        "acbUnspecified",
        "acbE",
        "acbP",
        "acbC",
        "acbG",
        "acbPg",
        "acbM",
        "acbMa15plus",
        "acbR18plus",
        "acbUnrated",
    ]
    agcomRating: typing_extensions.Literal[
        "agcomUnspecified", "agcomT", "agcomVm14", "agcomVm18", "agcomUnrated"
    ]
    anatelRating: typing_extensions.Literal[
        "anatelUnspecified",
        "anatelF",
        "anatelI",
        "anatelI7",
        "anatelI10",
        "anatelI12",
        "anatelR",
        "anatelA",
        "anatelUnrated",
    ]
    bbfcRating: typing_extensions.Literal[
        "bbfcUnspecified",
        "bbfcU",
        "bbfcPg",
        "bbfc12a",
        "bbfc12",
        "bbfc15",
        "bbfc18",
        "bbfcR18",
        "bbfcUnrated",
    ]
    bfvcRating: typing_extensions.Literal[
        "bfvcUnspecified",
        "bfvcG",
        "bfvcE",
        "bfvc13",
        "bfvc15",
        "bfvc18",
        "bfvc20",
        "bfvcB",
        "bfvcUnrated",
    ]
    bmukkRating: typing_extensions.Literal[
        "bmukkUnspecified",
        "bmukkAa",
        "bmukk6",
        "bmukk8",
        "bmukk10",
        "bmukk12",
        "bmukk14",
        "bmukk16",
        "bmukkUnrated",
    ]
    catvRating: typing_extensions.Literal[
        "catvUnspecified",
        "catvC",
        "catvC8",
        "catvG",
        "catvPg",
        "catv14plus",
        "catv18plus",
        "catvUnrated",
        "catvE",
    ]
    catvfrRating: typing_extensions.Literal[
        "catvfrUnspecified",
        "catvfrG",
        "catvfr8plus",
        "catvfr13plus",
        "catvfr16plus",
        "catvfr18plus",
        "catvfrUnrated",
        "catvfrE",
    ]
    cbfcRating: typing_extensions.Literal[
        "cbfcUnspecified",
        "cbfcU",
        "cbfcUA",
        "cbfcUA7plus",
        "cbfcUA13plus",
        "cbfcUA16plus",
        "cbfcA",
        "cbfcS",
        "cbfcUnrated",
    ]
    cccRating: typing_extensions.Literal[
        "cccUnspecified",
        "cccTe",
        "ccc6",
        "ccc14",
        "ccc18",
        "ccc18v",
        "ccc18s",
        "cccUnrated",
    ]
    cceRating: typing_extensions.Literal[
        "cceUnspecified",
        "cceM4",
        "cceM6",
        "cceM12",
        "cceM16",
        "cceM18",
        "cceUnrated",
        "cceM14",
    ]
    chfilmRating: typing_extensions.Literal[
        "chfilmUnspecified",
        "chfilm0",
        "chfilm6",
        "chfilm12",
        "chfilm16",
        "chfilm18",
        "chfilmUnrated",
    ]
    chvrsRating: typing_extensions.Literal[
        "chvrsUnspecified",
        "chvrsG",
        "chvrsPg",
        "chvrs14a",
        "chvrs18a",
        "chvrsR",
        "chvrsE",
        "chvrsUnrated",
    ]
    cicfRating: typing_extensions.Literal[
        "cicfUnspecified", "cicfE", "cicfKtEa", "cicfKntEna", "cicfUnrated"
    ]
    cnaRating: typing_extensions.Literal[
        "cnaUnspecified", "cnaAp", "cna12", "cna15", "cna18", "cna18plus", "cnaUnrated"
    ]
    cncRating: typing_extensions.Literal[
        "cncUnspecified",
        "cncT",
        "cnc10",
        "cnc12",
        "cnc16",
        "cnc18",
        "cncE",
        "cncInterdiction",
        "cncUnrated",
    ]
    csaRating: typing_extensions.Literal[
        "csaUnspecified",
        "csaT",
        "csa10",
        "csa12",
        "csa16",
        "csa18",
        "csaInterdiction",
        "csaUnrated",
    ]
    cscfRating: typing_extensions.Literal[
        "cscfUnspecified",
        "cscfAl",
        "cscfA",
        "cscf6",
        "cscf9",
        "cscf12",
        "cscf16",
        "cscf18",
        "cscfUnrated",
    ]
    czfilmRating: typing_extensions.Literal[
        "czfilmUnspecified",
        "czfilmU",
        "czfilm12",
        "czfilm14",
        "czfilm18",
        "czfilmUnrated",
    ]
    djctqRating: typing_extensions.Literal[
        "djctqUnspecified",
        "djctqL",
        "djctq10",
        "djctq12",
        "djctq14",
        "djctq16",
        "djctq18",
        "djctqEr",
        "djctqL10",
        "djctqL12",
        "djctqL14",
        "djctqL16",
        "djctqL18",
        "djctq1012",
        "djctq1014",
        "djctq1016",
        "djctq1018",
        "djctq1214",
        "djctq1216",
        "djctq1218",
        "djctq1416",
        "djctq1418",
        "djctq1618",
        "djctqUnrated",
    ]
    djctqRatingReasons: _list[str]
    ecbmctRating: typing_extensions.Literal[
        "ecbmctUnspecified",
        "ecbmctG",
        "ecbmct7a",
        "ecbmct7plus",
        "ecbmct13a",
        "ecbmct13plus",
        "ecbmct15a",
        "ecbmct15plus",
        "ecbmct18plus",
        "ecbmctUnrated",
    ]
    eefilmRating: typing_extensions.Literal[
        "eefilmUnspecified",
        "eefilmPere",
        "eefilmL",
        "eefilmMs6",
        "eefilmK6",
        "eefilmMs12",
        "eefilmK12",
        "eefilmK14",
        "eefilmK16",
        "eefilmUnrated",
    ]
    egfilmRating: typing_extensions.Literal[
        "egfilmUnspecified", "egfilmGn", "egfilm18", "egfilmBn", "egfilmUnrated"
    ]
    eirinRating: typing_extensions.Literal[
        "eirinUnspecified",
        "eirinG",
        "eirinPg12",
        "eirinR15plus",
        "eirinR18plus",
        "eirinUnrated",
    ]
    fcbmRating: typing_extensions.Literal[
        "fcbmUnspecified",
        "fcbmU",
        "fcbmPg13",
        "fcbmP13",
        "fcbm18",
        "fcbm18sx",
        "fcbm18pa",
        "fcbm18sg",
        "fcbm18pl",
        "fcbmUnrated",
    ]
    fcoRating: typing_extensions.Literal[
        "fcoUnspecified", "fcoI", "fcoIia", "fcoIib", "fcoIi", "fcoIii", "fcoUnrated"
    ]
    fmocRating: typing_extensions.Literal[
        "fmocUnspecified",
        "fmocU",
        "fmoc10",
        "fmoc12",
        "fmoc16",
        "fmoc18",
        "fmocE",
        "fmocUnrated",
    ]
    fpbRating: typing_extensions.Literal[
        "fpbUnspecified",
        "fpbA",
        "fpbPg",
        "fpb79Pg",
        "fpb1012Pg",
        "fpb13",
        "fpb16",
        "fpb18",
        "fpbX18",
        "fpbXx",
        "fpbUnrated",
        "fpb10",
    ]
    fpbRatingReasons: _list[str]
    fskRating: typing_extensions.Literal[
        "fskUnspecified", "fsk0", "fsk6", "fsk12", "fsk16", "fsk18", "fskUnrated"
    ]
    grfilmRating: typing_extensions.Literal[
        "grfilmUnspecified",
        "grfilmK",
        "grfilmE",
        "grfilmK12",
        "grfilmK13",
        "grfilmK15",
        "grfilmK17",
        "grfilmK18",
        "grfilmUnrated",
    ]
    icaaRating: typing_extensions.Literal[
        "icaaUnspecified",
        "icaaApta",
        "icaa7",
        "icaa12",
        "icaa13",
        "icaa16",
        "icaa18",
        "icaaX",
        "icaaUnrated",
    ]
    ifcoRating: typing_extensions.Literal[
        "ifcoUnspecified",
        "ifcoG",
        "ifcoPg",
        "ifco12",
        "ifco12a",
        "ifco15",
        "ifco15a",
        "ifco16",
        "ifco18",
        "ifcoUnrated",
    ]
    ilfilmRating: typing_extensions.Literal[
        "ilfilmUnspecified",
        "ilfilmAa",
        "ilfilm12",
        "ilfilm14",
        "ilfilm16",
        "ilfilm18",
        "ilfilmUnrated",
    ]
    incaaRating: typing_extensions.Literal[
        "incaaUnspecified",
        "incaaAtp",
        "incaaSam13",
        "incaaSam16",
        "incaaSam18",
        "incaaC",
        "incaaUnrated",
    ]
    kfcbRating: typing_extensions.Literal[
        "kfcbUnspecified", "kfcbG", "kfcbPg", "kfcb16plus", "kfcbR", "kfcbUnrated"
    ]
    kijkwijzerRating: typing_extensions.Literal[
        "kijkwijzerUnspecified",
        "kijkwijzerAl",
        "kijkwijzer6",
        "kijkwijzer9",
        "kijkwijzer12",
        "kijkwijzer16",
        "kijkwijzer18",
        "kijkwijzerUnrated",
    ]
    kmrbRating: typing_extensions.Literal[
        "kmrbUnspecified",
        "kmrbAll",
        "kmrb12plus",
        "kmrb15plus",
        "kmrbTeenr",
        "kmrbR",
        "kmrbUnrated",
    ]
    lsfRating: typing_extensions.Literal[
        "lsfUnspecified",
        "lsfSu",
        "lsfA",
        "lsfBo",
        "lsf13",
        "lsfR",
        "lsf17",
        "lsfD",
        "lsf21",
        "lsfUnrated",
    ]
    mccaaRating: typing_extensions.Literal[
        "mccaaUnspecified",
        "mccaaU",
        "mccaaPg",
        "mccaa12a",
        "mccaa12",
        "mccaa14",
        "mccaa15",
        "mccaa16",
        "mccaa18",
        "mccaaUnrated",
    ]
    mccypRating: typing_extensions.Literal[
        "mccypUnspecified", "mccypA", "mccyp7", "mccyp11", "mccyp15", "mccypUnrated"
    ]
    mcstRating: typing_extensions.Literal[
        "mcstUnspecified",
        "mcstP",
        "mcst0",
        "mcstC13",
        "mcstC16",
        "mcst16plus",
        "mcstC18",
        "mcstGPg",
        "mcstUnrated",
    ]
    mdaRating: typing_extensions.Literal[
        "mdaUnspecified",
        "mdaG",
        "mdaPg",
        "mdaPg13",
        "mdaNc16",
        "mdaM18",
        "mdaR21",
        "mdaUnrated",
    ]
    medietilsynetRating: typing_extensions.Literal[
        "medietilsynetUnspecified",
        "medietilsynetA",
        "medietilsynet6",
        "medietilsynet7",
        "medietilsynet9",
        "medietilsynet11",
        "medietilsynet12",
        "medietilsynet15",
        "medietilsynet18",
        "medietilsynetUnrated",
    ]
    mekuRating: typing_extensions.Literal[
        "mekuUnspecified", "mekuS", "meku7", "meku12", "meku16", "meku18", "mekuUnrated"
    ]
    menaMpaaRating: typing_extensions.Literal[
        "menaMpaaUnspecified",
        "menaMpaaG",
        "menaMpaaPg",
        "menaMpaaPg13",
        "menaMpaaR",
        "menaMpaaUnrated",
    ]
    mibacRating: typing_extensions.Literal[
        "mibacUnspecified",
        "mibacT",
        "mibacVap",
        "mibacVm6",
        "mibacVm12",
        "mibacVm14",
        "mibacVm16",
        "mibacVm18",
        "mibacUnrated",
    ]
    mocRating: typing_extensions.Literal[
        "mocUnspecified",
        "mocE",
        "mocT",
        "moc7",
        "moc12",
        "moc15",
        "moc18",
        "mocX",
        "mocBanned",
        "mocUnrated",
    ]
    moctwRating: typing_extensions.Literal[
        "moctwUnspecified",
        "moctwG",
        "moctwP",
        "moctwPg",
        "moctwR",
        "moctwUnrated",
        "moctwR12",
        "moctwR15",
    ]
    mpaaRating: typing_extensions.Literal[
        "mpaaUnspecified",
        "mpaaG",
        "mpaaPg",
        "mpaaPg13",
        "mpaaR",
        "mpaaNc17",
        "mpaaX",
        "mpaaUnrated",
    ]
    mpaatRating: typing_extensions.Literal["mpaatUnspecified", "mpaatGb", "mpaatRb"]
    mtrcbRating: typing_extensions.Literal[
        "mtrcbUnspecified",
        "mtrcbG",
        "mtrcbPg",
        "mtrcbR13",
        "mtrcbR16",
        "mtrcbR18",
        "mtrcbX",
        "mtrcbUnrated",
    ]
    nbcRating: typing_extensions.Literal[
        "nbcUnspecified",
        "nbcG",
        "nbcPg",
        "nbc12plus",
        "nbc15plus",
        "nbc18plus",
        "nbc18plusr",
        "nbcPu",
        "nbcUnrated",
    ]
    nbcplRating: typing_extensions.Literal[
        "nbcplUnspecified",
        "nbcplI",
        "nbcplIi",
        "nbcplIii",
        "nbcplIv",
        "nbcpl18plus",
        "nbcplUnrated",
    ]
    nfrcRating: typing_extensions.Literal[
        "nfrcUnspecified", "nfrcA", "nfrcB", "nfrcC", "nfrcD", "nfrcX", "nfrcUnrated"
    ]
    nfvcbRating: typing_extensions.Literal[
        "nfvcbUnspecified",
        "nfvcbG",
        "nfvcbPg",
        "nfvcb12",
        "nfvcb12a",
        "nfvcb15",
        "nfvcb18",
        "nfvcbRe",
        "nfvcbUnrated",
    ]
    nkclvRating: typing_extensions.Literal[
        "nkclvUnspecified",
        "nkclvU",
        "nkclv7plus",
        "nkclv12plus",
        "nkclv16plus",
        "nkclv18plus",
        "nkclvUnrated",
    ]
    nmcRating: typing_extensions.Literal[
        "nmcUnspecified",
        "nmcG",
        "nmcPg",
        "nmcPg13",
        "nmcPg15",
        "nmc15plus",
        "nmc18plus",
        "nmc18tc",
        "nmcUnrated",
    ]
    oflcRating: typing_extensions.Literal[
        "oflcUnspecified",
        "oflcG",
        "oflcPg",
        "oflcM",
        "oflcR13",
        "oflcR15",
        "oflcR16",
        "oflcR18",
        "oflcUnrated",
        "oflcRp13",
        "oflcRp16",
        "oflcRp18",
    ]
    pefilmRating: typing_extensions.Literal[
        "pefilmUnspecified",
        "pefilmPt",
        "pefilmPg",
        "pefilm14",
        "pefilm18",
        "pefilmUnrated",
    ]
    rcnofRating: typing_extensions.Literal[
        "rcnofUnspecified",
        "rcnofI",
        "rcnofIi",
        "rcnofIii",
        "rcnofIv",
        "rcnofV",
        "rcnofVi",
        "rcnofUnrated",
    ]
    resorteviolenciaRating: typing_extensions.Literal[
        "resorteviolenciaUnspecified",
        "resorteviolenciaA",
        "resorteviolenciaB",
        "resorteviolenciaC",
        "resorteviolenciaD",
        "resorteviolenciaE",
        "resorteviolenciaUnrated",
    ]
    rtcRating: typing_extensions.Literal[
        "rtcUnspecified",
        "rtcAa",
        "rtcA",
        "rtcB",
        "rtcB15",
        "rtcC",
        "rtcD",
        "rtcUnrated",
    ]
    rteRating: typing_extensions.Literal[
        "rteUnspecified", "rteGa", "rteCh", "rtePs", "rteMa", "rteUnrated"
    ]
    russiaRating: typing_extensions.Literal[
        "russiaUnspecified",
        "russia0",
        "russia6",
        "russia12",
        "russia16",
        "russia18",
        "russiaUnrated",
    ]
    skfilmRating: typing_extensions.Literal[
        "skfilmUnspecified",
        "skfilmG",
        "skfilmP2",
        "skfilmP5",
        "skfilmP8",
        "skfilmUnrated",
    ]
    smaisRating: typing_extensions.Literal[
        "smaisUnspecified",
        "smaisL",
        "smais7",
        "smais12",
        "smais14",
        "smais16",
        "smais18",
        "smaisUnrated",
    ]
    smsaRating: typing_extensions.Literal[
        "smsaUnspecified", "smsaA", "smsa7", "smsa11", "smsa15", "smsaUnrated"
    ]
    tvpgRating: typing_extensions.Literal[
        "tvpgUnspecified",
        "tvpgY",
        "tvpgY7",
        "tvpgY7Fv",
        "tvpgG",
        "tvpgPg",
        "pg14",
        "tvpgMa",
        "tvpgUnrated",
    ]
    ytRating: typing_extensions.Literal["ytUnspecified", "ytAgeRestricted"]

@typing.type_check_only
class Cuepoint(typing_extensions.TypedDict, total=False):
    cueType: typing_extensions.Literal["cueTypeUnspecified", "cueTypeAd"]
    durationSecs: int
    etag: str
    id: str
    insertionOffsetTimeMs: str
    walltimeMs: str

@typing.type_check_only
class Entity(typing_extensions.TypedDict, total=False):
    id: str
    typeId: str
    url: str

@typing.type_check_only
class GeoPoint(typing_extensions.TypedDict, total=False):
    altitude: float
    latitude: float
    longitude: float

@typing.type_check_only
class I18nLanguage(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    snippet: I18nLanguageSnippet

@typing.type_check_only
class I18nLanguageListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[I18nLanguage]
    kind: str
    visitorId: str

@typing.type_check_only
class I18nLanguageSnippet(typing_extensions.TypedDict, total=False):
    hl: str
    name: str

@typing.type_check_only
class I18nRegion(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    snippet: I18nRegionSnippet

@typing.type_check_only
class I18nRegionListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[I18nRegion]
    kind: str
    visitorId: str

@typing.type_check_only
class I18nRegionSnippet(typing_extensions.TypedDict, total=False):
    gl: str
    name: str

@typing.type_check_only
class ImageSettings(typing_extensions.TypedDict, total=False):
    backgroundImageUrl: LocalizedProperty
    bannerExternalUrl: str
    bannerImageUrl: str
    bannerMobileExtraHdImageUrl: str
    bannerMobileHdImageUrl: str
    bannerMobileImageUrl: str
    bannerMobileLowImageUrl: str
    bannerMobileMediumHdImageUrl: str
    bannerTabletExtraHdImageUrl: str
    bannerTabletHdImageUrl: str
    bannerTabletImageUrl: str
    bannerTabletLowImageUrl: str
    bannerTvHighImageUrl: str
    bannerTvImageUrl: str
    bannerTvLowImageUrl: str
    bannerTvMediumImageUrl: str
    largeBrandedBannerImageImapScript: LocalizedProperty
    largeBrandedBannerImageUrl: LocalizedProperty
    smallBrandedBannerImageImapScript: LocalizedProperty
    smallBrandedBannerImageUrl: LocalizedProperty
    trackingImageUrl: str
    watchIconImageUrl: str

@typing.type_check_only
class IngestionInfo(typing_extensions.TypedDict, total=False):
    backupIngestionAddress: str
    ingestionAddress: str
    rtmpsBackupIngestionAddress: str
    rtmpsIngestionAddress: str
    streamName: str

@typing.type_check_only
class InvideoBranding(typing_extensions.TypedDict, total=False):
    imageBytes: str
    imageUrl: str
    position: InvideoPosition
    targetChannelId: str
    timing: InvideoTiming

@typing.type_check_only
class InvideoPosition(typing_extensions.TypedDict, total=False):
    cornerPosition: typing_extensions.Literal[
        "topLeft", "topRight", "bottomLeft", "bottomRight"
    ]
    type: typing_extensions.Literal["corner"]

@typing.type_check_only
class InvideoTiming(typing_extensions.TypedDict, total=False):
    durationMs: str
    offsetMs: str
    type: typing_extensions.Literal["offsetFromStart", "offsetFromEnd"]

@typing.type_check_only
class LanguageTag(typing_extensions.TypedDict, total=False):
    value: str

@typing.type_check_only
class LevelDetails(typing_extensions.TypedDict, total=False):
    displayName: str

@typing.type_check_only
class LiveBroadcast(typing_extensions.TypedDict, total=False):
    contentDetails: LiveBroadcastContentDetails
    etag: str
    id: str
    kind: str
    snippet: LiveBroadcastSnippet
    statistics: LiveBroadcastStatistics
    status: LiveBroadcastStatus

@typing.type_check_only
class LiveBroadcastContentDetails(typing_extensions.TypedDict, total=False):
    boundStreamId: str
    boundStreamLastUpdateTimeMs: str
    closedCaptionsType: typing_extensions.Literal[
        "closedCaptionsTypeUnspecified",
        "closedCaptionsDisabled",
        "closedCaptionsHttpPost",
        "closedCaptionsEmbedded",
    ]
    enableAutoStart: bool
    enableAutoStop: bool
    enableClosedCaptions: bool
    enableContentEncryption: bool
    enableDvr: bool
    enableEmbed: bool
    enableLowLatency: bool
    latencyPreference: typing_extensions.Literal[
        "latencyPreferenceUnspecified", "normal", "low", "ultraLow"
    ]
    mesh: str
    monitorStream: MonitorStreamInfo
    projection: typing_extensions.Literal[
        "projectionUnspecified", "rectangular", "360", "mesh"
    ]
    recordFromStart: bool
    startWithSlate: bool
    stereoLayout: typing_extensions.Literal[
        "stereoLayoutUnspecified", "mono", "leftRight", "topBottom"
    ]

@typing.type_check_only
class LiveBroadcastListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[LiveBroadcast]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    prevPageToken: str
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class LiveBroadcastSnippet(typing_extensions.TypedDict, total=False):
    actualEndTime: str
    actualStartTime: str
    channelId: str
    description: str
    isDefaultBroadcast: bool
    liveChatId: str
    publishedAt: str
    scheduledEndTime: str
    scheduledStartTime: str
    thumbnails: ThumbnailDetails
    title: str

@typing.type_check_only
class LiveBroadcastStatistics(typing_extensions.TypedDict, total=False):
    concurrentViewers: str
    totalChatCount: str

@typing.type_check_only
class LiveBroadcastStatus(typing_extensions.TypedDict, total=False):
    lifeCycleStatus: typing_extensions.Literal[
        "lifeCycleStatusUnspecified",
        "created",
        "ready",
        "testing",
        "live",
        "complete",
        "revoked",
        "testStarting",
        "liveStarting",
    ]
    liveBroadcastPriority: typing_extensions.Literal[
        "liveBroadcastPriorityUnspecified", "low", "normal", "high"
    ]
    madeForKids: bool
    privacyStatus: typing_extensions.Literal["public", "unlisted", "private"]
    recordingStatus: typing_extensions.Literal[
        "liveBroadcastRecordingStatusUnspecified",
        "notRecording",
        "recording",
        "recorded",
    ]
    selfDeclaredMadeForKids: bool

@typing.type_check_only
class LiveChatBan(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    snippet: LiveChatBanSnippet

@typing.type_check_only
class LiveChatBanSnippet(typing_extensions.TypedDict, total=False):
    banDurationSeconds: str
    bannedUserDetails: ChannelProfileDetails
    liveChatId: str
    type: typing_extensions.Literal[
        "liveChatBanTypeUnspecified", "permanent", "temporary"
    ]

@typing.type_check_only
class LiveChatFanFundingEventDetails(typing_extensions.TypedDict, total=False):
    amountDisplayString: str
    amountMicros: str
    currency: str
    userComment: str

@typing.type_check_only
class LiveChatGiftMembershipReceivedDetails(typing_extensions.TypedDict, total=False):
    associatedMembershipGiftingMessageId: str
    gifterChannelId: str
    memberLevelName: str

@typing.type_check_only
class LiveChatMemberMilestoneChatDetails(typing_extensions.TypedDict, total=False):
    memberLevelName: str
    memberMonth: int
    userComment: str

@typing.type_check_only
class LiveChatMembershipGiftingDetails(typing_extensions.TypedDict, total=False):
    giftMembershipsCount: int
    giftMembershipsLevelName: str

@typing.type_check_only
class LiveChatMessage(typing_extensions.TypedDict, total=False):
    authorDetails: LiveChatMessageAuthorDetails
    etag: str
    id: str
    kind: str
    snippet: LiveChatMessageSnippet

@typing.type_check_only
class LiveChatMessageAuthorDetails(typing_extensions.TypedDict, total=False):
    channelId: str
    channelUrl: str
    displayName: str
    isChatModerator: bool
    isChatOwner: bool
    isChatSponsor: bool
    isVerified: bool
    profileImageUrl: str

@typing.type_check_only
class LiveChatMessageDeletedDetails(typing_extensions.TypedDict, total=False):
    deletedMessageId: str

@typing.type_check_only
class LiveChatMessageListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[LiveChatMessage]
    kind: str
    nextPageToken: str
    offlineAt: str
    pageInfo: PageInfo
    pollingIntervalMillis: int
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class LiveChatMessageRetractedDetails(typing_extensions.TypedDict, total=False):
    retractedMessageId: str

@typing.type_check_only
class LiveChatMessageSnippet(typing_extensions.TypedDict, total=False):
    authorChannelId: str
    displayMessage: str
    fanFundingEventDetails: LiveChatFanFundingEventDetails
    giftMembershipReceivedDetails: LiveChatGiftMembershipReceivedDetails
    hasDisplayContent: bool
    liveChatId: str
    memberMilestoneChatDetails: LiveChatMemberMilestoneChatDetails
    membershipGiftingDetails: LiveChatMembershipGiftingDetails
    messageDeletedDetails: LiveChatMessageDeletedDetails
    messageRetractedDetails: LiveChatMessageRetractedDetails
    newSponsorDetails: LiveChatNewSponsorDetails
    publishedAt: str
    superChatDetails: LiveChatSuperChatDetails
    superStickerDetails: LiveChatSuperStickerDetails
    textMessageDetails: LiveChatTextMessageDetails
    type: typing_extensions.Literal[
        "invalidType",
        "textMessageEvent",
        "tombstone",
        "fanFundingEvent",
        "chatEndedEvent",
        "sponsorOnlyModeStartedEvent",
        "sponsorOnlyModeEndedEvent",
        "newSponsorEvent",
        "memberMilestoneChatEvent",
        "membershipGiftingEvent",
        "giftMembershipReceivedEvent",
        "messageDeletedEvent",
        "messageRetractedEvent",
        "userBannedEvent",
        "superChatEvent",
        "superStickerEvent",
    ]
    userBannedDetails: LiveChatUserBannedMessageDetails

@typing.type_check_only
class LiveChatModerator(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    snippet: LiveChatModeratorSnippet

@typing.type_check_only
class LiveChatModeratorListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[LiveChatModerator]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    prevPageToken: str
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class LiveChatModeratorSnippet(typing_extensions.TypedDict, total=False):
    liveChatId: str
    moderatorDetails: ChannelProfileDetails

@typing.type_check_only
class LiveChatNewSponsorDetails(typing_extensions.TypedDict, total=False):
    isUpgrade: bool
    memberLevelName: str

@typing.type_check_only
class LiveChatSuperChatDetails(typing_extensions.TypedDict, total=False):
    amountDisplayString: str
    amountMicros: str
    currency: str
    tier: int
    userComment: str

@typing.type_check_only
class LiveChatSuperStickerDetails(typing_extensions.TypedDict, total=False):
    amountDisplayString: str
    amountMicros: str
    currency: str
    superStickerMetadata: SuperStickerMetadata
    tier: int

@typing.type_check_only
class LiveChatTextMessageDetails(typing_extensions.TypedDict, total=False):
    messageText: str

@typing.type_check_only
class LiveChatUserBannedMessageDetails(typing_extensions.TypedDict, total=False):
    banDurationSeconds: str
    banType: typing_extensions.Literal["permanent", "temporary"]
    bannedUserDetails: ChannelProfileDetails

@typing.type_check_only
class LiveStream(typing_extensions.TypedDict, total=False):
    cdn: CdnSettings
    contentDetails: LiveStreamContentDetails
    etag: str
    id: str
    kind: str
    snippet: LiveStreamSnippet
    status: LiveStreamStatus

@typing.type_check_only
class LiveStreamConfigurationIssue(typing_extensions.TypedDict, total=False):
    description: str
    reason: str
    severity: typing_extensions.Literal["info", "warning", "error"]
    type: typing_extensions.Literal[
        "gopSizeOver",
        "gopSizeLong",
        "gopSizeShort",
        "openGop",
        "badContainer",
        "audioBitrateHigh",
        "audioBitrateLow",
        "audioSampleRate",
        "bitrateHigh",
        "bitrateLow",
        "audioCodec",
        "videoCodec",
        "noAudioStream",
        "noVideoStream",
        "multipleVideoStreams",
        "multipleAudioStreams",
        "audioTooManyChannels",
        "interlacedVideo",
        "frameRateHigh",
        "resolutionMismatch",
        "videoCodecMismatch",
        "videoInterlaceMismatch",
        "videoProfileMismatch",
        "videoBitrateMismatch",
        "framerateMismatch",
        "gopMismatch",
        "audioSampleRateMismatch",
        "audioStereoMismatch",
        "audioCodecMismatch",
        "audioBitrateMismatch",
        "videoResolutionSuboptimal",
        "videoResolutionUnsupported",
        "videoIngestionStarved",
        "videoIngestionFasterThanRealtime",
    ]

@typing.type_check_only
class LiveStreamContentDetails(typing_extensions.TypedDict, total=False):
    closedCaptionsIngestionUrl: str
    isReusable: bool

@typing.type_check_only
class LiveStreamHealthStatus(typing_extensions.TypedDict, total=False):
    configurationIssues: _list[LiveStreamConfigurationIssue]
    lastUpdateTimeSeconds: str
    status: typing_extensions.Literal["good", "ok", "bad", "noData", "revoked"]

@typing.type_check_only
class LiveStreamListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[LiveStream]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    prevPageToken: str
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class LiveStreamSnippet(typing_extensions.TypedDict, total=False):
    channelId: str
    description: str
    isDefaultStream: bool
    publishedAt: str
    title: str

@typing.type_check_only
class LiveStreamStatus(typing_extensions.TypedDict, total=False):
    healthStatus: LiveStreamHealthStatus
    streamStatus: typing_extensions.Literal[
        "created", "ready", "active", "inactive", "error"
    ]

@typing.type_check_only
class LocalizedProperty(typing_extensions.TypedDict, total=False):
    default: str
    defaultLanguage: LanguageTag
    localized: _list[LocalizedString]

@typing.type_check_only
class LocalizedString(typing_extensions.TypedDict, total=False):
    language: str
    value: str

@typing.type_check_only
class Member(typing_extensions.TypedDict, total=False):
    etag: str
    kind: str
    snippet: MemberSnippet

@typing.type_check_only
class MemberListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[Member]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class MemberSnippet(typing_extensions.TypedDict, total=False):
    creatorChannelId: str
    memberDetails: ChannelProfileDetails
    membershipsDetails: MembershipsDetails

@typing.type_check_only
class MembershipsDetails(typing_extensions.TypedDict, total=False):
    accessibleLevels: _list[str]
    highestAccessibleLevel: str
    highestAccessibleLevelDisplayName: str
    membershipsDuration: MembershipsDuration
    membershipsDurationAtLevels: _list[MembershipsDurationAtLevel]

@typing.type_check_only
class MembershipsDuration(typing_extensions.TypedDict, total=False):
    memberSince: str
    memberTotalDurationMonths: int

@typing.type_check_only
class MembershipsDurationAtLevel(typing_extensions.TypedDict, total=False):
    level: str
    memberSince: str
    memberTotalDurationMonths: int

@typing.type_check_only
class MembershipsLevel(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    snippet: MembershipsLevelSnippet

@typing.type_check_only
class MembershipsLevelListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[MembershipsLevel]
    kind: str
    visitorId: str

@typing.type_check_only
class MembershipsLevelSnippet(typing_extensions.TypedDict, total=False):
    creatorChannelId: str
    levelDetails: LevelDetails

@typing.type_check_only
class MonitorStreamInfo(typing_extensions.TypedDict, total=False):
    broadcastStreamDelayMs: int
    embedHtml: str
    enableMonitorStream: bool

@typing.type_check_only
class PageInfo(typing_extensions.TypedDict, total=False):
    resultsPerPage: int
    totalResults: int

@typing.type_check_only
class Playlist(typing_extensions.TypedDict, total=False):
    contentDetails: PlaylistContentDetails
    etag: str
    id: str
    kind: str
    localizations: dict[str, typing.Any]
    player: PlaylistPlayer
    snippet: PlaylistSnippet
    status: PlaylistStatus

@typing.type_check_only
class PlaylistContentDetails(typing_extensions.TypedDict, total=False):
    itemCount: int

@typing.type_check_only
class PlaylistItem(typing_extensions.TypedDict, total=False):
    contentDetails: PlaylistItemContentDetails
    etag: str
    id: str
    kind: str
    snippet: PlaylistItemSnippet
    status: PlaylistItemStatus

@typing.type_check_only
class PlaylistItemContentDetails(typing_extensions.TypedDict, total=False):
    endAt: str
    note: str
    startAt: str
    videoId: str
    videoPublishedAt: str

@typing.type_check_only
class PlaylistItemListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[PlaylistItem]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    prevPageToken: str
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class PlaylistItemSnippet(typing_extensions.TypedDict, total=False):
    channelId: str
    channelTitle: str
    description: str
    playlistId: str
    position: int
    publishedAt: str
    resourceId: ResourceId
    thumbnails: ThumbnailDetails
    title: str
    videoOwnerChannelId: str
    videoOwnerChannelTitle: str

@typing.type_check_only
class PlaylistItemStatus(typing_extensions.TypedDict, total=False):
    privacyStatus: typing_extensions.Literal["public", "unlisted", "private"]

@typing.type_check_only
class PlaylistListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[Playlist]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    prevPageToken: str
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class PlaylistLocalization(typing_extensions.TypedDict, total=False):
    description: str
    title: str

@typing.type_check_only
class PlaylistPlayer(typing_extensions.TypedDict, total=False):
    embedHtml: str

@typing.type_check_only
class PlaylistSnippet(typing_extensions.TypedDict, total=False):
    channelId: str
    channelTitle: str
    defaultLanguage: str
    description: str
    localized: PlaylistLocalization
    publishedAt: str
    tags: _list[str]
    thumbnailVideoId: str
    thumbnails: ThumbnailDetails
    title: str

@typing.type_check_only
class PlaylistStatus(typing_extensions.TypedDict, total=False):
    privacyStatus: typing_extensions.Literal["public", "unlisted", "private"]

@typing.type_check_only
class PropertyValue(typing_extensions.TypedDict, total=False):
    property: str
    value: str

@typing.type_check_only
class RelatedEntity(typing_extensions.TypedDict, total=False):
    entity: Entity

@typing.type_check_only
class ResourceId(typing_extensions.TypedDict, total=False):
    channelId: str
    kind: str
    playlistId: str
    videoId: str

@typing.type_check_only
class SearchListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[SearchResult]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    prevPageToken: str
    regionCode: str
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class SearchResult(typing_extensions.TypedDict, total=False):
    etag: str
    id: ResourceId
    kind: str
    snippet: SearchResultSnippet

@typing.type_check_only
class SearchResultSnippet(typing_extensions.TypedDict, total=False):
    channelId: str
    channelTitle: str
    description: str
    liveBroadcastContent: typing_extensions.Literal[
        "none", "upcoming", "live", "completed"
    ]
    publishedAt: str
    thumbnails: ThumbnailDetails
    title: str

@typing.type_check_only
class Subscription(typing_extensions.TypedDict, total=False):
    contentDetails: SubscriptionContentDetails
    etag: str
    id: str
    kind: str
    snippet: SubscriptionSnippet
    subscriberSnippet: SubscriptionSubscriberSnippet

@typing.type_check_only
class SubscriptionContentDetails(typing_extensions.TypedDict, total=False):
    activityType: typing_extensions.Literal[
        "subscriptionActivityTypeUnspecified", "all", "uploads"
    ]
    newItemCount: int
    totalItemCount: int

@typing.type_check_only
class SubscriptionListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[Subscription]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    prevPageToken: str
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class SubscriptionSnippet(typing_extensions.TypedDict, total=False):
    channelId: str
    channelTitle: str
    description: str
    publishedAt: str
    resourceId: ResourceId
    thumbnails: ThumbnailDetails
    title: str

@typing.type_check_only
class SubscriptionSubscriberSnippet(typing_extensions.TypedDict, total=False):
    channelId: str
    description: str
    thumbnails: ThumbnailDetails
    title: str

@typing.type_check_only
class SuperChatEvent(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    snippet: SuperChatEventSnippet

@typing.type_check_only
class SuperChatEventListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[SuperChatEvent]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class SuperChatEventSnippet(typing_extensions.TypedDict, total=False):
    amountMicros: str
    channelId: str
    commentText: str
    createdAt: str
    currency: str
    displayString: str
    isSuperStickerEvent: bool
    messageType: int
    superStickerMetadata: SuperStickerMetadata
    supporterDetails: ChannelProfileDetails

@typing.type_check_only
class SuperStickerMetadata(typing_extensions.TypedDict, total=False):
    altText: str
    altTextLanguage: str
    stickerId: str

@typing.type_check_only
class TestItem(typing_extensions.TypedDict, total=False):
    featuredPart: bool
    gaia: str
    id: str
    snippet: TestItemTestItemSnippet

@typing.type_check_only
class TestItemTestItemSnippet(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ThirdPartyLink(typing_extensions.TypedDict, total=False):
    etag: str
    kind: str
    linkingToken: str
    snippet: ThirdPartyLinkSnippet
    status: ThirdPartyLinkStatus

@typing.type_check_only
class ThirdPartyLinkListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    items: _list[ThirdPartyLink]
    kind: str

@typing.type_check_only
class ThirdPartyLinkSnippet(typing_extensions.TypedDict, total=False):
    channelToStoreLink: ChannelToStoreLinkDetails
    type: typing_extensions.Literal["linkUnspecified", "channelToStoreLink"]

@typing.type_check_only
class ThirdPartyLinkStatus(typing_extensions.TypedDict, total=False):
    linkStatus: typing_extensions.Literal["unknown", "failed", "pending", "linked"]

@typing.type_check_only
class Thumbnail(typing_extensions.TypedDict, total=False):
    height: int
    url: str
    width: int

@typing.type_check_only
class ThumbnailDetails(typing_extensions.TypedDict, total=False):
    default: Thumbnail
    high: Thumbnail
    maxres: Thumbnail
    medium: Thumbnail
    standard: Thumbnail

@typing.type_check_only
class ThumbnailSetResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[ThumbnailDetails]
    kind: str
    visitorId: str

@typing.type_check_only
class TokenPagination(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Video(typing_extensions.TypedDict, total=False):
    ageGating: VideoAgeGating
    contentDetails: VideoContentDetails
    etag: str
    fileDetails: VideoFileDetails
    id: str
    kind: str
    liveStreamingDetails: VideoLiveStreamingDetails
    localizations: dict[str, typing.Any]
    monetizationDetails: VideoMonetizationDetails
    player: VideoPlayer
    processingDetails: VideoProcessingDetails
    projectDetails: VideoProjectDetails
    recordingDetails: VideoRecordingDetails
    snippet: VideoSnippet
    statistics: VideoStatistics
    status: VideoStatus
    suggestions: VideoSuggestions
    topicDetails: VideoTopicDetails

@typing.type_check_only
class VideoAbuseReport(typing_extensions.TypedDict, total=False):
    comments: str
    language: str
    reasonId: str
    secondaryReasonId: str
    videoId: str

@typing.type_check_only
class VideoAbuseReportReason(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    snippet: VideoAbuseReportReasonSnippet

@typing.type_check_only
class VideoAbuseReportReasonListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[VideoAbuseReportReason]
    kind: str
    visitorId: str

@typing.type_check_only
class VideoAbuseReportReasonSnippet(typing_extensions.TypedDict, total=False):
    label: str
    secondaryReasons: _list[VideoAbuseReportSecondaryReason]

@typing.type_check_only
class VideoAbuseReportSecondaryReason(typing_extensions.TypedDict, total=False):
    id: str
    label: str

@typing.type_check_only
class VideoAgeGating(typing_extensions.TypedDict, total=False):
    alcoholContent: bool
    restricted: bool
    videoGameRating: typing_extensions.Literal[
        "anyone", "m15Plus", "m16Plus", "m17Plus"
    ]

@typing.type_check_only
class VideoCategory(typing_extensions.TypedDict, total=False):
    etag: str
    id: str
    kind: str
    snippet: VideoCategorySnippet

@typing.type_check_only
class VideoCategoryListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[VideoCategory]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    prevPageToken: str
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class VideoCategorySnippet(typing_extensions.TypedDict, total=False):
    assignable: bool
    channelId: str
    title: str

@typing.type_check_only
class VideoContentDetails(typing_extensions.TypedDict, total=False):
    caption: typing_extensions.Literal["true", "false"]
    contentRating: ContentRating
    countryRestriction: AccessPolicy
    definition: typing_extensions.Literal["sd", "hd"]
    dimension: str
    duration: str
    hasCustomThumbnail: bool
    licensedContent: bool
    projection: typing_extensions.Literal["rectangular", "360"]
    regionRestriction: VideoContentDetailsRegionRestriction

@typing.type_check_only
class VideoContentDetailsRegionRestriction(typing_extensions.TypedDict, total=False):
    allowed: _list[str]
    blocked: _list[str]

@typing.type_check_only
class VideoFileDetails(typing_extensions.TypedDict, total=False):
    audioStreams: _list[VideoFileDetailsAudioStream]
    bitrateBps: str
    container: str
    creationTime: str
    durationMs: str
    fileName: str
    fileSize: str
    fileType: typing_extensions.Literal[
        "video", "audio", "image", "archive", "document", "project", "other"
    ]
    videoStreams: _list[VideoFileDetailsVideoStream]

@typing.type_check_only
class VideoFileDetailsAudioStream(typing_extensions.TypedDict, total=False):
    bitrateBps: str
    channelCount: int
    codec: str
    vendor: str

@typing.type_check_only
class VideoFileDetailsVideoStream(typing_extensions.TypedDict, total=False):
    aspectRatio: float
    bitrateBps: str
    codec: str
    frameRateFps: float
    heightPixels: int
    rotation: typing_extensions.Literal[
        "none", "clockwise", "upsideDown", "counterClockwise", "other"
    ]
    vendor: str
    widthPixels: int

@typing.type_check_only
class VideoGetRatingResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[VideoRating]
    kind: str
    visitorId: str

@typing.type_check_only
class VideoListResponse(typing_extensions.TypedDict, total=False):
    etag: str
    eventId: str
    items: _list[Video]
    kind: str
    nextPageToken: str
    pageInfo: PageInfo
    prevPageToken: str
    tokenPagination: TokenPagination
    visitorId: str

@typing.type_check_only
class VideoLiveStreamingDetails(typing_extensions.TypedDict, total=False):
    activeLiveChatId: str
    actualEndTime: str
    actualStartTime: str
    concurrentViewers: str
    scheduledEndTime: str
    scheduledStartTime: str

@typing.type_check_only
class VideoLocalization(typing_extensions.TypedDict, total=False):
    description: str
    title: str

@typing.type_check_only
class VideoMonetizationDetails(typing_extensions.TypedDict, total=False):
    access: AccessPolicy

@typing.type_check_only
class VideoPlayer(typing_extensions.TypedDict, total=False):
    embedHeight: str
    embedHtml: str
    embedWidth: str

@typing.type_check_only
class VideoProcessingDetails(typing_extensions.TypedDict, total=False):
    editorSuggestionsAvailability: str
    fileDetailsAvailability: str
    processingFailureReason: typing_extensions.Literal[
        "uploadFailed", "transcodeFailed", "streamingFailed", "other"
    ]
    processingIssuesAvailability: str
    processingProgress: VideoProcessingDetailsProcessingProgress
    processingStatus: typing_extensions.Literal[
        "processing", "succeeded", "failed", "terminated"
    ]
    tagSuggestionsAvailability: str
    thumbnailsAvailability: str

@typing.type_check_only
class VideoProcessingDetailsProcessingProgress(
    typing_extensions.TypedDict, total=False
):
    partsProcessed: str
    partsTotal: str
    timeLeftMs: str

@typing.type_check_only
class VideoProjectDetails(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class VideoRating(typing_extensions.TypedDict, total=False):
    rating: typing_extensions.Literal["none", "like", "dislike"]
    videoId: str

@typing.type_check_only
class VideoRecordingDetails(typing_extensions.TypedDict, total=False):
    location: GeoPoint
    locationDescription: str
    recordingDate: str

@typing.type_check_only
class VideoSnippet(typing_extensions.TypedDict, total=False):
    categoryId: str
    channelId: str
    channelTitle: str
    defaultAudioLanguage: str
    defaultLanguage: str
    description: str
    liveBroadcastContent: typing_extensions.Literal[
        "none", "upcoming", "live", "completed"
    ]
    localized: VideoLocalization
    publishedAt: str
    tags: _list[str]
    thumbnails: ThumbnailDetails
    title: str

@typing.type_check_only
class VideoStatistics(typing_extensions.TypedDict, total=False):
    commentCount: str
    dislikeCount: str
    favoriteCount: str
    likeCount: str
    viewCount: str

@typing.type_check_only
class VideoStatus(typing_extensions.TypedDict, total=False):
    embeddable: bool
    failureReason: typing_extensions.Literal[
        "conversion", "invalidFile", "emptyFile", "tooSmall", "codec", "uploadAborted"
    ]
    license: typing_extensions.Literal["youtube", "creativeCommon"]
    madeForKids: bool
    privacyStatus: typing_extensions.Literal["public", "unlisted", "private"]
    publicStatsViewable: bool
    publishAt: str
    rejectionReason: typing_extensions.Literal[
        "copyright",
        "inappropriate",
        "duplicate",
        "termsOfUse",
        "uploaderAccountSuspended",
        "length",
        "claim",
        "uploaderAccountClosed",
        "trademark",
        "legal",
    ]
    selfDeclaredMadeForKids: bool
    uploadStatus: typing_extensions.Literal[
        "uploaded", "processed", "failed", "rejected", "deleted"
    ]

@typing.type_check_only
class VideoSuggestions(typing_extensions.TypedDict, total=False):
    editorSuggestions: _list[str]
    processingErrors: _list[str]
    processingHints: _list[str]
    processingWarnings: _list[str]
    tagSuggestions: _list[VideoSuggestionsTagSuggestion]

@typing.type_check_only
class VideoSuggestionsTagSuggestion(typing_extensions.TypedDict, total=False):
    categoryRestricts: _list[str]
    tag: str

@typing.type_check_only
class VideoTopicDetails(typing_extensions.TypedDict, total=False):
    relevantTopicIds: _list[str]
    topicCategories: _list[str]
    topicIds: _list[str]

@typing.type_check_only
class WatchSettings(typing_extensions.TypedDict, total=False):
    backgroundColor: str
    featuredPlaylistId: str
    textColor: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AuditConfig(typing_extensions.TypedDict, total=False):
    auditLogConfigs: _list[AuditLogConfig]
    service: str

@typing.type_check_only
class AuditLogConfig(typing_extensions.TypedDict, total=False):
    exemptedMembers: _list[str]
    logType: typing_extensions.Literal[
        "LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"
    ]

@typing.type_check_only
class AuthConfig(typing_extensions.TypedDict, total=False):
    additionalVariables: _list[ConfigVariable]
    authType: typing_extensions.Literal[
        "AUTH_TYPE_UNSPECIFIED",
        "USER_PASSWORD",
        "OAUTH2_JWT_BEARER",
        "OAUTH2_CLIENT_CREDENTIALS",
        "SSH_PUBLIC_KEY",
        "OAUTH2_AUTH_CODE_FLOW",
    ]
    oauth2ClientCredentials: Oauth2ClientCredentials
    oauth2JwtBearer: Oauth2JwtBearer
    sshPublicKey: SshPublicKey
    userPassword: UserPassword

@typing.type_check_only
class AuthConfigTemplate(typing_extensions.TypedDict, total=False):
    authType: typing_extensions.Literal[
        "AUTH_TYPE_UNSPECIFIED",
        "USER_PASSWORD",
        "OAUTH2_JWT_BEARER",
        "OAUTH2_CLIENT_CREDENTIALS",
        "SSH_PUBLIC_KEY",
        "OAUTH2_AUTH_CODE_FLOW",
    ]
    configVariableTemplates: _list[ConfigVariableTemplate]

@typing.type_check_only
class AuthorizationCodeLink(typing_extensions.TypedDict, total=False):
    clientId: str
    enablePkce: bool
    scopes: _list[str]
    uri: str

@typing.type_check_only
class Binding(typing_extensions.TypedDict, total=False):
    condition: Expr
    members: _list[str]
    role: str

@typing.type_check_only
class CancelOperationRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ConfigVariable(typing_extensions.TypedDict, total=False):
    boolValue: bool
    intValue: str
    key: str
    secretValue: Secret
    stringValue: str

@typing.type_check_only
class ConfigVariableTemplate(typing_extensions.TypedDict, total=False):
    authorizationCodeLink: AuthorizationCodeLink
    description: str
    displayName: str
    enumOptions: _list[EnumOption]
    key: str
    required: bool
    roleGrant: RoleGrant
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "ACTIVE", "DEPRECATED"]
    validationRegex: str
    valueType: typing_extensions.Literal[
        "VALUE_TYPE_UNSPECIFIED",
        "STRING",
        "INT",
        "BOOL",
        "SECRET",
        "ENUM",
        "AUTHORIZATION_CODE",
    ]

@typing.type_check_only
class Connection(typing_extensions.TypedDict, total=False):
    authConfig: AuthConfig
    configVariables: _list[ConfigVariable]
    connectorVersion: str
    createTime: str
    description: str
    destinationConfigs: _list[DestinationConfig]
    envoyImageLocation: str
    imageLocation: str
    labels: dict[str, typing.Any]
    lockConfig: LockConfig
    name: str
    nodeConfig: NodeConfig
    serviceAccount: str
    serviceDirectory: str
    status: ConnectionStatus
    suspended: bool
    updateTime: str

@typing.type_check_only
class ConnectionSchemaMetadata(typing_extensions.TypedDict, total=False):
    actions: _list[str]
    entities: _list[str]

@typing.type_check_only
class ConnectionStatus(typing_extensions.TypedDict, total=False):
    description: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "CREATING",
        "ACTIVE",
        "INACTIVE",
        "DELETING",
        "UPDATING",
        "ERROR",
    ]
    status: str

@typing.type_check_only
class Connector(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    displayName: str
    documentationUri: str
    externalUri: str
    labels: dict[str, typing.Any]
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED", "PREVIEW", "GA", "DEPRECATED"
    ]
    name: str
    updateTime: str
    webAssetsLocation: str

@typing.type_check_only
class ConnectorVersion(typing_extensions.TypedDict, total=False):
    authConfigTemplates: _list[AuthConfigTemplate]
    configVariableTemplates: _list[ConfigVariableTemplate]
    createTime: str
    displayName: str
    egressControlConfig: EgressControlConfig
    labels: dict[str, typing.Any]
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED", "PREVIEW", "GA", "DEPRECATED"
    ]
    name: str
    releaseVersion: str
    roleGrant: RoleGrant
    roleGrants: _list[RoleGrant]
    supportedRuntimeFeatures: SupportedRuntimeFeatures
    updateTime: str

@typing.type_check_only
class Destination(typing_extensions.TypedDict, total=False):
    host: str
    port: int
    serviceAttachment: str

@typing.type_check_only
class DestinationConfig(typing_extensions.TypedDict, total=False):
    destinations: _list[Destination]
    key: str

@typing.type_check_only
class EgressControlConfig(typing_extensions.TypedDict, total=False):
    backends: str
    extractionRules: ExtractionRules

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class EnumOption(typing_extensions.TypedDict, total=False):
    displayName: str
    id: str

@typing.type_check_only
class Expr(typing_extensions.TypedDict, total=False):
    description: str
    expression: str
    location: str
    title: str

@typing.type_check_only
class ExtractionRule(typing_extensions.TypedDict, total=False):
    extractionRegex: str
    source: Source

@typing.type_check_only
class ExtractionRules(typing_extensions.TypedDict, total=False):
    extractionRule: _list[ExtractionRule]

@typing.type_check_only
class Field(typing_extensions.TypedDict, total=False):
    additionalDetails: dict[str, typing.Any]
    dataType: typing_extensions.Literal[
        "DATA_TYPE_UNSPECIFIED",
        "DATA_TYPE_INT",
        "DATA_TYPE_SMALLINT",
        "DATA_TYPE_DOUBLE",
        "DATA_TYPE_DATE",
        "DATA_TYPE_DATETIME",
        "DATA_TYPE_TIME",
        "DATA_TYPE_STRING",
        "DATA_TYPE_LONG",
        "DATA_TYPE_BOOLEAN",
        "DATA_TYPE_DECIMAL",
        "DATA_TYPE_UUID",
        "DATA_TYPE_BLOB",
        "DATA_TYPE_BIT",
        "DATA_TYPE_TINYINT",
        "DATA_TYPE_INTEGER",
        "DATA_TYPE_BIGINT",
        "DATA_TYPE_FLOAT",
        "DATA_TYPE_REAL",
        "DATA_TYPE_NUMERIC",
        "DATA_TYPE_CHAR",
        "DATA_TYPE_VARCHAR",
        "DATA_TYPE_LONGVARCHAR",
        "DATA_TYPE_TIMESTAMP",
        "DATA_TYPE_NCHAR",
        "DATA_TYPE_NVARCHAR",
        "DATA_TYPE_LONGNVARCHAR",
        "DATA_TYPE_NULL",
        "DATA_TYPE_OTHER",
        "DATA_TYPE_JAVA_OBJECT",
        "DATA_TYPE_DISTINCT",
        "DATA_TYPE_STRUCT",
        "DATA_TYPE_ARRAY",
        "DATA_TYPE_CLOB",
        "DATA_TYPE_REF",
        "DATA_TYPE_DATALINK",
        "DATA_TYPE_ROWID",
        "DATA_TYPE_BINARY",
        "DATA_TYPE_VARBINARY",
        "DATA_TYPE_LONGVARBINARY",
        "DATA_TYPE_NCLOB",
        "DATA_TYPE_SQLXML",
        "DATA_TYPE_REF_CURSOR",
        "DATA_TYPE_TIME_WITH_TIMEZONE",
        "DATA_TYPE_TIMESTAMP_WITH_TIMEZONE",
    ]
    defaultValue: typing.Any
    description: str
    field: str
    key: bool
    nullable: bool
    readonly: bool

@typing.type_check_only
class InputParameter(typing_extensions.TypedDict, total=False):
    dataType: typing_extensions.Literal[
        "DATA_TYPE_UNSPECIFIED",
        "DATA_TYPE_INT",
        "DATA_TYPE_SMALLINT",
        "DATA_TYPE_DOUBLE",
        "DATA_TYPE_DATE",
        "DATA_TYPE_DATETIME",
        "DATA_TYPE_TIME",
        "DATA_TYPE_STRING",
        "DATA_TYPE_LONG",
        "DATA_TYPE_BOOLEAN",
        "DATA_TYPE_DECIMAL",
        "DATA_TYPE_UUID",
        "DATA_TYPE_BLOB",
        "DATA_TYPE_BIT",
        "DATA_TYPE_TINYINT",
        "DATA_TYPE_INTEGER",
        "DATA_TYPE_BIGINT",
        "DATA_TYPE_FLOAT",
        "DATA_TYPE_REAL",
        "DATA_TYPE_NUMERIC",
        "DATA_TYPE_CHAR",
        "DATA_TYPE_VARCHAR",
        "DATA_TYPE_LONGVARCHAR",
        "DATA_TYPE_TIMESTAMP",
        "DATA_TYPE_NCHAR",
        "DATA_TYPE_NVARCHAR",
        "DATA_TYPE_LONGNVARCHAR",
        "DATA_TYPE_NULL",
        "DATA_TYPE_OTHER",
        "DATA_TYPE_JAVA_OBJECT",
        "DATA_TYPE_DISTINCT",
        "DATA_TYPE_STRUCT",
        "DATA_TYPE_ARRAY",
        "DATA_TYPE_CLOB",
        "DATA_TYPE_REF",
        "DATA_TYPE_DATALINK",
        "DATA_TYPE_ROWID",
        "DATA_TYPE_BINARY",
        "DATA_TYPE_VARBINARY",
        "DATA_TYPE_LONGVARBINARY",
        "DATA_TYPE_NCLOB",
        "DATA_TYPE_SQLXML",
        "DATA_TYPE_REF_CURSOR",
        "DATA_TYPE_TIME_WITH_TIMEZONE",
        "DATA_TYPE_TIMESTAMP_WITH_TIMEZONE",
    ]
    defaultValue: typing.Any
    description: str
    nullable: bool
    parameter: str

@typing.type_check_only
class JwtClaims(typing_extensions.TypedDict, total=False):
    audience: str
    issuer: str
    subject: str

@typing.type_check_only
class ListConnectionsResponse(typing_extensions.TypedDict, total=False):
    connections: _list[Connection]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListConnectorVersionsResponse(typing_extensions.TypedDict, total=False):
    connectorVersions: _list[ConnectorVersion]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListConnectorsResponse(typing_extensions.TypedDict, total=False):
    connectors: _list[Connector]
    nextPageToken: str
    unreachable: _list[str]

@typing.type_check_only
class ListLocationsResponse(typing_extensions.TypedDict, total=False):
    locations: _list[Location]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListProvidersResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    providers: _list[Provider]
    unreachable: _list[str]

@typing.type_check_only
class ListRuntimeActionSchemasResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    runtimeActionSchemas: _list[RuntimeActionSchema]

@typing.type_check_only
class ListRuntimeEntitySchemasResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    runtimeEntitySchemas: _list[RuntimeEntitySchema]

@typing.type_check_only
class Location(typing_extensions.TypedDict, total=False):
    displayName: str
    labels: dict[str, typing.Any]
    locationId: str
    metadata: dict[str, typing.Any]
    name: str

@typing.type_check_only
class LockConfig(typing_extensions.TypedDict, total=False):
    locked: bool
    reason: str

@typing.type_check_only
class NodeConfig(typing_extensions.TypedDict, total=False):
    maxNodeCount: int
    minNodeCount: int

@typing.type_check_only
class Oauth2ClientCredentials(typing_extensions.TypedDict, total=False):
    clientId: str
    clientSecret: Secret

@typing.type_check_only
class Oauth2JwtBearer(typing_extensions.TypedDict, total=False):
    clientKey: Secret
    jwtClaims: JwtClaims

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    apiVersion: str
    createTime: str
    endTime: str
    requestedCancellation: bool
    statusMessage: str
    target: str
    verb: str

@typing.type_check_only
class Policy(typing_extensions.TypedDict, total=False):
    auditConfigs: _list[AuditConfig]
    bindings: _list[Binding]
    etag: str
    version: int

@typing.type_check_only
class Provider(typing_extensions.TypedDict, total=False):
    createTime: str
    description: str
    displayName: str
    documentationUri: str
    externalUri: str
    labels: dict[str, typing.Any]
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED", "PREVIEW", "GA", "DEPRECATED"
    ]
    name: str
    updateTime: str
    webAssetsLocation: str

@typing.type_check_only
class Resource(typing_extensions.TypedDict, total=False):
    pathTemplate: str
    type: typing_extensions.Literal[
        "TYPE_UNSPECIFIED",
        "GCP_PROJECT",
        "GCP_RESOURCE",
        "GCP_SECRETMANAGER_SECRET",
        "GCP_SECRETMANAGER_SECRET_VERSION",
    ]

@typing.type_check_only
class ResultMetadata(typing_extensions.TypedDict, total=False):
    dataType: typing_extensions.Literal[
        "DATA_TYPE_UNSPECIFIED",
        "DATA_TYPE_INT",
        "DATA_TYPE_SMALLINT",
        "DATA_TYPE_DOUBLE",
        "DATA_TYPE_DATE",
        "DATA_TYPE_DATETIME",
        "DATA_TYPE_TIME",
        "DATA_TYPE_STRING",
        "DATA_TYPE_LONG",
        "DATA_TYPE_BOOLEAN",
        "DATA_TYPE_DECIMAL",
        "DATA_TYPE_UUID",
        "DATA_TYPE_BLOB",
        "DATA_TYPE_BIT",
        "DATA_TYPE_TINYINT",
        "DATA_TYPE_INTEGER",
        "DATA_TYPE_BIGINT",
        "DATA_TYPE_FLOAT",
        "DATA_TYPE_REAL",
        "DATA_TYPE_NUMERIC",
        "DATA_TYPE_CHAR",
        "DATA_TYPE_VARCHAR",
        "DATA_TYPE_LONGVARCHAR",
        "DATA_TYPE_TIMESTAMP",
        "DATA_TYPE_NCHAR",
        "DATA_TYPE_NVARCHAR",
        "DATA_TYPE_LONGNVARCHAR",
        "DATA_TYPE_NULL",
        "DATA_TYPE_OTHER",
        "DATA_TYPE_JAVA_OBJECT",
        "DATA_TYPE_DISTINCT",
        "DATA_TYPE_STRUCT",
        "DATA_TYPE_ARRAY",
        "DATA_TYPE_CLOB",
        "DATA_TYPE_REF",
        "DATA_TYPE_DATALINK",
        "DATA_TYPE_ROWID",
        "DATA_TYPE_BINARY",
        "DATA_TYPE_VARBINARY",
        "DATA_TYPE_LONGVARBINARY",
        "DATA_TYPE_NCLOB",
        "DATA_TYPE_SQLXML",
        "DATA_TYPE_REF_CURSOR",
        "DATA_TYPE_TIME_WITH_TIMEZONE",
        "DATA_TYPE_TIMESTAMP_WITH_TIMEZONE",
    ]
    description: str
    field: str

@typing.type_check_only
class RoleGrant(typing_extensions.TypedDict, total=False):
    helperTextTemplate: str
    principal: typing_extensions.Literal["PRINCIPAL_UNSPECIFIED", "CONNECTOR_SA"]
    resource: Resource
    roles: _list[str]

@typing.type_check_only
class RuntimeActionSchema(typing_extensions.TypedDict, total=False):
    action: str
    inputParameters: _list[InputParameter]
    resultMetadata: _list[ResultMetadata]

@typing.type_check_only
class RuntimeConfig(typing_extensions.TypedDict, total=False):
    conndSubscription: str
    conndTopic: str
    controlPlaneSubscription: str
    controlPlaneTopic: str
    locationId: str
    name: str
    runtimeEndpoint: str
    schemaGcsBucket: str
    serviceDirectory: str
    state: typing_extensions.Literal[
        "STATE_UNSPECIFIED",
        "INACTIVE",
        "ACTIVATING",
        "ACTIVE",
        "CREATING",
        "DELETING",
        "UPDATING",
    ]

@typing.type_check_only
class RuntimeEntitySchema(typing_extensions.TypedDict, total=False):
    entity: str
    fields: _list[Field]

@typing.type_check_only
class Secret(typing_extensions.TypedDict, total=False):
    secretVersion: str

@typing.type_check_only
class SetIamPolicyRequest(typing_extensions.TypedDict, total=False):
    policy: Policy
    updateMask: str

@typing.type_check_only
class Source(typing_extensions.TypedDict, total=False):
    fieldId: str
    sourceType: typing_extensions.Literal["SOURCE_TYPE_UNSPECIFIED", "CONFIG_VARIABLE"]

@typing.type_check_only
class SshPublicKey(typing_extensions.TypedDict, total=False):
    certType: str
    password: Secret
    sshClientCert: Secret
    sshClientCertPass: Secret
    username: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class SupportedRuntimeFeatures(typing_extensions.TypedDict, total=False):
    actionApis: bool
    entityApis: bool
    sqlQuery: bool

@typing.type_check_only
class TestIamPermissionsRequest(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class TestIamPermissionsResponse(typing_extensions.TypedDict, total=False):
    permissions: _list[str]

@typing.type_check_only
class UserPassword(typing_extensions.TypedDict, total=False):
    password: Secret
    username: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class ClassItem(typing_extensions.TypedDict, total=False):
    value: str

@typing.type_check_only
class CreateCustomClassRequest(typing_extensions.TypedDict, total=False):
    customClass: CustomClass
    customClassId: str

@typing.type_check_only
class CreatePhraseSetRequest(typing_extensions.TypedDict, total=False):
    phraseSet: PhraseSet
    phraseSetId: str

@typing.type_check_only
class CustomClass(typing_extensions.TypedDict, total=False):
    customClassId: str
    items: _list[ClassItem]
    name: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Entry(typing_extensions.TypedDict, total=False):
    caseSensitive: bool
    replace: str
    search: str

@typing.type_check_only
class ListCustomClassesResponse(typing_extensions.TypedDict, total=False):
    customClasses: _list[CustomClass]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListPhraseSetResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    phraseSets: _list[PhraseSet]

@typing.type_check_only
class LongRunningRecognizeMetadata(typing_extensions.TypedDict, total=False):
    lastUpdateTime: str
    outputConfig: TranscriptOutputConfig
    progressPercent: int
    startTime: str
    uri: str

@typing.type_check_only
class LongRunningRecognizeRequest(typing_extensions.TypedDict, total=False):
    audio: RecognitionAudio
    config: RecognitionConfig
    outputConfig: TranscriptOutputConfig

@typing.type_check_only
class LongRunningRecognizeResponse(typing_extensions.TypedDict, total=False):
    outputConfig: TranscriptOutputConfig
    outputError: Status
    requestId: str
    results: _list[SpeechRecognitionResult]
    totalBilledTime: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class Phrase(typing_extensions.TypedDict, total=False):
    boost: float
    value: str

@typing.type_check_only
class PhraseSet(typing_extensions.TypedDict, total=False):
    boost: float
    name: str
    phrases: _list[Phrase]

@typing.type_check_only
class RecognitionAudio(typing_extensions.TypedDict, total=False):
    content: str
    uri: str

@typing.type_check_only
class RecognitionConfig(typing_extensions.TypedDict, total=False):
    adaptation: SpeechAdaptation
    alternativeLanguageCodes: _list[str]
    audioChannelCount: int
    diarizationConfig: SpeakerDiarizationConfig
    diarizationSpeakerCount: int
    enableAutomaticPunctuation: bool
    enableSeparateRecognitionPerChannel: bool
    enableSpeakerDiarization: bool
    enableSpokenEmojis: bool
    enableSpokenPunctuation: bool
    enableWordConfidence: bool
    enableWordTimeOffsets: bool
    encoding: typing_extensions.Literal[
        "ENCODING_UNSPECIFIED",
        "LINEAR16",
        "FLAC",
        "MULAW",
        "AMR",
        "AMR_WB",
        "OGG_OPUS",
        "SPEEX_WITH_HEADER_BYTE",
        "MP3",
        "WEBM_OPUS",
    ]
    languageCode: str
    maxAlternatives: int
    metadata: RecognitionMetadata
    model: str
    profanityFilter: bool
    sampleRateHertz: int
    speechContexts: _list[SpeechContext]
    transcriptNormalization: TranscriptNormalization
    useEnhanced: bool

@typing.type_check_only
class RecognitionMetadata(typing_extensions.TypedDict, total=False):
    audioTopic: str
    industryNaicsCodeOfAudio: int
    interactionType: typing_extensions.Literal[
        "INTERACTION_TYPE_UNSPECIFIED",
        "DISCUSSION",
        "PRESENTATION",
        "PHONE_CALL",
        "VOICEMAIL",
        "PROFESSIONALLY_PRODUCED",
        "VOICE_SEARCH",
        "VOICE_COMMAND",
        "DICTATION",
    ]
    microphoneDistance: typing_extensions.Literal[
        "MICROPHONE_DISTANCE_UNSPECIFIED", "NEARFIELD", "MIDFIELD", "FARFIELD"
    ]
    obfuscatedId: str
    originalMediaType: typing_extensions.Literal[
        "ORIGINAL_MEDIA_TYPE_UNSPECIFIED", "AUDIO", "VIDEO"
    ]
    originalMimeType: str
    recordingDeviceName: str
    recordingDeviceType: typing_extensions.Literal[
        "RECORDING_DEVICE_TYPE_UNSPECIFIED",
        "SMARTPHONE",
        "PC",
        "PHONE_LINE",
        "VEHICLE",
        "OTHER_OUTDOOR_DEVICE",
        "OTHER_INDOOR_DEVICE",
    ]

@typing.type_check_only
class RecognizeRequest(typing_extensions.TypedDict, total=False):
    audio: RecognitionAudio
    config: RecognitionConfig

@typing.type_check_only
class RecognizeResponse(typing_extensions.TypedDict, total=False):
    requestId: str
    results: _list[SpeechRecognitionResult]
    totalBilledTime: str

@typing.type_check_only
class SpeakerDiarizationConfig(typing_extensions.TypedDict, total=False):
    enableSpeakerDiarization: bool
    maxSpeakerCount: int
    minSpeakerCount: int
    speakerTag: int

@typing.type_check_only
class SpeechAdaptation(typing_extensions.TypedDict, total=False):
    customClasses: _list[CustomClass]
    phraseSetReferences: _list[str]
    phraseSets: _list[PhraseSet]

@typing.type_check_only
class SpeechContext(typing_extensions.TypedDict, total=False):
    boost: float
    phrases: _list[str]

@typing.type_check_only
class SpeechRecognitionAlternative(typing_extensions.TypedDict, total=False):
    confidence: float
    transcript: str
    words: _list[WordInfo]

@typing.type_check_only
class SpeechRecognitionResult(typing_extensions.TypedDict, total=False):
    alternatives: _list[SpeechRecognitionAlternative]
    channelTag: int
    languageCode: str
    resultEndTime: str

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class TranscriptNormalization(typing_extensions.TypedDict, total=False):
    entries: _list[Entry]

@typing.type_check_only
class TranscriptOutputConfig(typing_extensions.TypedDict, total=False):
    gcsUri: str

@typing.type_check_only
class WordInfo(typing_extensions.TypedDict, total=False):
    confidence: float
    endTime: str
    speakerTag: int
    startTime: str
    word: str



import typing

import typing_extensions

_list = list

@typing.type_check_only
class AdminQuotaPolicy(typing_extensions.TypedDict, total=False):
    container: str
    dimensions: dict[str, typing.Any]
    metric: str
    name: str
    policyValue: str
    unit: str

@typing.type_check_only
class Api(typing_extensions.TypedDict, total=False):
    methods: _list[Method]
    mixins: _list[Mixin]
    name: str
    options: _list[Option]
    sourceContext: SourceContext
    syntax: typing_extensions.Literal["SYNTAX_PROTO2", "SYNTAX_PROTO3"]
    version: str

@typing.type_check_only
class AuthProvider(typing_extensions.TypedDict, total=False):
    audiences: str
    authorizationUrl: str
    id: str
    issuer: str
    jwksUri: str
    jwtLocations: _list[JwtLocation]

@typing.type_check_only
class AuthRequirement(typing_extensions.TypedDict, total=False):
    audiences: str
    providerId: str

@typing.type_check_only
class Authentication(typing_extensions.TypedDict, total=False):
    providers: _list[AuthProvider]
    rules: _list[AuthenticationRule]

@typing.type_check_only
class AuthenticationRule(typing_extensions.TypedDict, total=False):
    allowWithoutCredential: bool
    oauth: OAuthRequirements
    requirements: _list[AuthRequirement]
    selector: str

@typing.type_check_only
class Backend(typing_extensions.TypedDict, total=False):
    rules: _list[BackendRule]

@typing.type_check_only
class BackendRule(typing_extensions.TypedDict, total=False):
    address: str
    deadline: float
    disableAuth: bool
    jwtAudience: str
    operationDeadline: float
    pathTranslation: typing_extensions.Literal[
        "PATH_TRANSLATION_UNSPECIFIED", "CONSTANT_ADDRESS", "APPEND_PATH_TO_ADDRESS"
    ]
    protocol: str
    selector: str

@typing.type_check_only
class BatchCreateAdminOverridesResponse(typing_extensions.TypedDict, total=False):
    overrides: _list[QuotaOverride]

@typing.type_check_only
class BatchCreateConsumerOverridesResponse(typing_extensions.TypedDict, total=False):
    overrides: _list[QuotaOverride]

@typing.type_check_only
class BatchEnableServicesRequest(typing_extensions.TypedDict, total=False):
    serviceIds: _list[str]

@typing.type_check_only
class BatchEnableServicesResponse(typing_extensions.TypedDict, total=False):
    failures: _list[EnableFailure]
    services: _list[GoogleApiServiceusageV1Service]

@typing.type_check_only
class Billing(typing_extensions.TypedDict, total=False):
    consumerDestinations: _list[BillingDestination]

@typing.type_check_only
class BillingDestination(typing_extensions.TypedDict, total=False):
    metrics: _list[str]
    monitoredResource: str

@typing.type_check_only
class ConsumerQuotaLimit(typing_extensions.TypedDict, total=False):
    allowsAdminOverrides: bool
    isPrecise: bool
    metric: str
    name: str
    quotaBuckets: _list[QuotaBucket]
    supportedLocations: _list[str]
    unit: str

@typing.type_check_only
class ConsumerQuotaMetric(typing_extensions.TypedDict, total=False):
    consumerQuotaLimits: _list[ConsumerQuotaLimit]
    descendantConsumerQuotaLimits: _list[ConsumerQuotaLimit]
    displayName: str
    metric: str
    name: str
    unit: str

@typing.type_check_only
class Context(typing_extensions.TypedDict, total=False):
    rules: _list[ContextRule]

@typing.type_check_only
class ContextRule(typing_extensions.TypedDict, total=False):
    allowedRequestExtensions: _list[str]
    allowedResponseExtensions: _list[str]
    provided: _list[str]
    requested: _list[str]
    selector: str

@typing.type_check_only
class Control(typing_extensions.TypedDict, total=False):
    environment: str

@typing.type_check_only
class CreateAdminQuotaPolicyMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class CustomError(typing_extensions.TypedDict, total=False):
    rules: _list[CustomErrorRule]
    types: _list[str]

@typing.type_check_only
class CustomErrorRule(typing_extensions.TypedDict, total=False):
    isErrorType: bool
    selector: str

@typing.type_check_only
class CustomHttpPattern(typing_extensions.TypedDict, total=False):
    kind: str
    path: str

@typing.type_check_only
class DeleteAdminQuotaPolicyMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DisableServiceRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class DisableServiceResponse(typing_extensions.TypedDict, total=False):
    service: GoogleApiServiceusageV1Service

@typing.type_check_only
class Documentation(typing_extensions.TypedDict, total=False):
    documentationRootUrl: str
    overview: str
    pages: _list[Page]
    rules: _list[DocumentationRule]
    serviceRootUrl: str
    summary: str

@typing.type_check_only
class DocumentationRule(typing_extensions.TypedDict, total=False):
    deprecationDescription: str
    description: str
    selector: str

@typing.type_check_only
class Empty(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class EnableFailure(typing_extensions.TypedDict, total=False):
    errorMessage: str
    serviceId: str

@typing.type_check_only
class EnableServiceRequest(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class EnableServiceResponse(typing_extensions.TypedDict, total=False):
    service: GoogleApiServiceusageV1Service

@typing.type_check_only
class Endpoint(typing_extensions.TypedDict, total=False):
    allowCors: bool
    name: str
    target: str

@typing.type_check_only
class Enum(typing_extensions.TypedDict, total=False):
    enumvalue: _list[EnumValue]
    name: str
    options: _list[Option]
    sourceContext: SourceContext
    syntax: typing_extensions.Literal["SYNTAX_PROTO2", "SYNTAX_PROTO3"]

@typing.type_check_only
class EnumValue(typing_extensions.TypedDict, total=False):
    name: str
    number: int
    options: _list[Option]

@typing.type_check_only
class Field(typing_extensions.TypedDict, total=False):
    cardinality: typing_extensions.Literal[
        "CARDINALITY_UNKNOWN",
        "CARDINALITY_OPTIONAL",
        "CARDINALITY_REQUIRED",
        "CARDINALITY_REPEATED",
    ]
    defaultValue: str
    jsonName: str
    kind: typing_extensions.Literal[
        "TYPE_UNKNOWN",
        "TYPE_DOUBLE",
        "TYPE_FLOAT",
        "TYPE_INT64",
        "TYPE_UINT64",
        "TYPE_INT32",
        "TYPE_FIXED64",
        "TYPE_FIXED32",
        "TYPE_BOOL",
        "TYPE_STRING",
        "TYPE_GROUP",
        "TYPE_MESSAGE",
        "TYPE_BYTES",
        "TYPE_UINT32",
        "TYPE_ENUM",
        "TYPE_SFIXED32",
        "TYPE_SFIXED64",
        "TYPE_SINT32",
        "TYPE_SINT64",
    ]
    name: str
    number: int
    oneofIndex: int
    options: _list[Option]
    packed: bool
    typeUrl: str

@typing.type_check_only
class GetServiceIdentityMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class GetServiceIdentityResponse(typing_extensions.TypedDict, total=False):
    identity: ServiceIdentity
    state: typing_extensions.Literal["IDENTITY_STATE_UNSPECIFIED", "ACTIVE"]

@typing.type_check_only
class GoogleApiService(typing_extensions.TypedDict, total=False):
    apis: _list[Api]
    authentication: Authentication
    backend: Backend
    billing: Billing
    configVersion: int
    context: Context
    control: Control
    customError: CustomError
    documentation: Documentation
    endpoints: _list[Endpoint]
    enums: _list[Enum]
    http: Http
    id: str
    logging: Logging
    logs: _list[LogDescriptor]
    metrics: _list[MetricDescriptor]
    monitoredResources: _list[MonitoredResourceDescriptor]
    monitoring: Monitoring
    name: str
    producerProjectId: str
    quota: Quota
    sourceInfo: SourceInfo
    systemParameters: SystemParameters
    systemTypes: _list[Type]
    title: str
    types: _list[Type]
    usage: Usage

@typing.type_check_only
class GoogleApiServiceusageV1OperationMetadata(
    typing_extensions.TypedDict, total=False
):
    resourceNames: _list[str]

@typing.type_check_only
class GoogleApiServiceusageV1Service(typing_extensions.TypedDict, total=False):
    config: GoogleApiServiceusageV1ServiceConfig
    name: str
    parent: str
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "DISABLED", "ENABLED"]

@typing.type_check_only
class GoogleApiServiceusageV1ServiceConfig(typing_extensions.TypedDict, total=False):
    apis: _list[Api]
    authentication: Authentication
    documentation: Documentation
    endpoints: _list[Endpoint]
    monitoredResources: _list[MonitoredResourceDescriptor]
    monitoring: Monitoring
    name: str
    quota: Quota
    title: str
    usage: Usage

@typing.type_check_only
class GoogleApiServiceusageV1beta1GetServiceIdentityResponse(
    typing_extensions.TypedDict, total=False
):
    identity: GoogleApiServiceusageV1beta1ServiceIdentity
    state: typing_extensions.Literal["IDENTITY_STATE_UNSPECIFIED", "ACTIVE"]

@typing.type_check_only
class GoogleApiServiceusageV1beta1ServiceIdentity(
    typing_extensions.TypedDict, total=False
):
    email: str
    uniqueId: str

@typing.type_check_only
class Http(typing_extensions.TypedDict, total=False):
    fullyDecodeReservedExpansion: bool
    rules: _list[HttpRule]

@typing.type_check_only
class HttpRule(typing_extensions.TypedDict, total=False):
    additionalBindings: _list[HttpRule]
    body: str
    custom: CustomHttpPattern
    delete: str
    get: str
    patch: str
    post: str
    put: str
    responseBody: str
    selector: str

@typing.type_check_only
class ImportAdminOverridesMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ImportAdminOverridesRequest(typing_extensions.TypedDict, total=False):
    force: bool
    forceOnly: _list[str]
    inlineSource: OverrideInlineSource

@typing.type_check_only
class ImportAdminOverridesResponse(typing_extensions.TypedDict, total=False):
    overrides: _list[QuotaOverride]

@typing.type_check_only
class ImportAdminQuotaPoliciesMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ImportAdminQuotaPoliciesResponse(typing_extensions.TypedDict, total=False):
    policies: _list[AdminQuotaPolicy]

@typing.type_check_only
class ImportConsumerOverridesMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class ImportConsumerOverridesRequest(typing_extensions.TypedDict, total=False):
    force: bool
    forceOnly: _list[str]
    inlineSource: OverrideInlineSource

@typing.type_check_only
class ImportConsumerOverridesResponse(typing_extensions.TypedDict, total=False):
    overrides: _list[QuotaOverride]

@typing.type_check_only
class JwtLocation(typing_extensions.TypedDict, total=False):
    cookie: str
    header: str
    query: str
    valuePrefix: str

@typing.type_check_only
class LabelDescriptor(typing_extensions.TypedDict, total=False):
    description: str
    key: str
    valueType: typing_extensions.Literal["STRING", "BOOL", "INT64"]

@typing.type_check_only
class ListAdminOverridesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    overrides: _list[QuotaOverride]

@typing.type_check_only
class ListConsumerOverridesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    overrides: _list[QuotaOverride]

@typing.type_check_only
class ListConsumerQuotaMetricsResponse(typing_extensions.TypedDict, total=False):
    metrics: _list[ConsumerQuotaMetric]
    nextPageToken: str

@typing.type_check_only
class ListOperationsResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    operations: _list[Operation]

@typing.type_check_only
class ListServicesResponse(typing_extensions.TypedDict, total=False):
    nextPageToken: str
    services: _list[Service]

@typing.type_check_only
class LogDescriptor(typing_extensions.TypedDict, total=False):
    description: str
    displayName: str
    labels: _list[LabelDescriptor]
    name: str

@typing.type_check_only
class Logging(typing_extensions.TypedDict, total=False):
    consumerDestinations: _list[LoggingDestination]
    producerDestinations: _list[LoggingDestination]

@typing.type_check_only
class LoggingDestination(typing_extensions.TypedDict, total=False):
    logs: _list[str]
    monitoredResource: str

@typing.type_check_only
class Method(typing_extensions.TypedDict, total=False):
    name: str
    options: _list[Option]
    requestStreaming: bool
    requestTypeUrl: str
    responseStreaming: bool
    responseTypeUrl: str
    syntax: typing_extensions.Literal["SYNTAX_PROTO2", "SYNTAX_PROTO3"]

@typing.type_check_only
class MetricDescriptor(typing_extensions.TypedDict, total=False):
    description: str
    displayName: str
    labels: _list[LabelDescriptor]
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED",
        "UNIMPLEMENTED",
        "PRELAUNCH",
        "EARLY_ACCESS",
        "ALPHA",
        "BETA",
        "GA",
        "DEPRECATED",
    ]
    metadata: MetricDescriptorMetadata
    metricKind: typing_extensions.Literal[
        "METRIC_KIND_UNSPECIFIED", "GAUGE", "DELTA", "CUMULATIVE"
    ]
    monitoredResourceTypes: _list[str]
    name: str
    type: str
    unit: str
    valueType: typing_extensions.Literal[
        "VALUE_TYPE_UNSPECIFIED",
        "BOOL",
        "INT64",
        "DOUBLE",
        "STRING",
        "DISTRIBUTION",
        "MONEY",
    ]

@typing.type_check_only
class MetricDescriptorMetadata(typing_extensions.TypedDict, total=False):
    ingestDelay: str
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED",
        "UNIMPLEMENTED",
        "PRELAUNCH",
        "EARLY_ACCESS",
        "ALPHA",
        "BETA",
        "GA",
        "DEPRECATED",
    ]
    samplePeriod: str

@typing.type_check_only
class MetricRule(typing_extensions.TypedDict, total=False):
    metricCosts: dict[str, typing.Any]
    selector: str

@typing.type_check_only
class Mixin(typing_extensions.TypedDict, total=False):
    name: str
    root: str

@typing.type_check_only
class MonitoredResourceDescriptor(typing_extensions.TypedDict, total=False):
    description: str
    displayName: str
    labels: _list[LabelDescriptor]
    launchStage: typing_extensions.Literal[
        "LAUNCH_STAGE_UNSPECIFIED",
        "UNIMPLEMENTED",
        "PRELAUNCH",
        "EARLY_ACCESS",
        "ALPHA",
        "BETA",
        "GA",
        "DEPRECATED",
    ]
    name: str
    type: str

@typing.type_check_only
class Monitoring(typing_extensions.TypedDict, total=False):
    consumerDestinations: _list[MonitoringDestination]
    producerDestinations: _list[MonitoringDestination]

@typing.type_check_only
class MonitoringDestination(typing_extensions.TypedDict, total=False):
    metrics: _list[str]
    monitoredResource: str

@typing.type_check_only
class OAuthRequirements(typing_extensions.TypedDict, total=False):
    canonicalScopes: str

@typing.type_check_only
class Operation(typing_extensions.TypedDict, total=False):
    done: bool
    error: Status
    metadata: dict[str, typing.Any]
    name: str
    response: dict[str, typing.Any]

@typing.type_check_only
class OperationMetadata(typing_extensions.TypedDict, total=False):
    resourceNames: _list[str]

@typing.type_check_only
class Option(typing_extensions.TypedDict, total=False):
    name: str
    value: dict[str, typing.Any]

@typing.type_check_only
class OverrideInlineSource(typing_extensions.TypedDict, total=False):
    overrides: _list[QuotaOverride]

@typing.type_check_only
class Page(typing_extensions.TypedDict, total=False):
    content: str
    name: str
    subpages: _list[Page]

@typing.type_check_only
class Quota(typing_extensions.TypedDict, total=False):
    limits: _list[QuotaLimit]
    metricRules: _list[MetricRule]

@typing.type_check_only
class QuotaBucket(typing_extensions.TypedDict, total=False):
    adminOverride: QuotaOverride
    consumerOverride: QuotaOverride
    defaultLimit: str
    dimensions: dict[str, typing.Any]
    effectiveLimit: str
    producerOverride: QuotaOverride

@typing.type_check_only
class QuotaLimit(typing_extensions.TypedDict, total=False):
    defaultLimit: str
    description: str
    displayName: str
    duration: str
    freeTier: str
    maxLimit: str
    metric: str
    name: str
    unit: str
    values: dict[str, typing.Any]

@typing.type_check_only
class QuotaOverride(typing_extensions.TypedDict, total=False):
    adminOverrideAncestor: str
    dimensions: dict[str, typing.Any]
    metric: str
    name: str
    overrideValue: str
    unit: str

@typing.type_check_only
class Service(typing_extensions.TypedDict, total=False):
    config: ServiceConfig
    name: str
    parent: str
    state: typing_extensions.Literal["STATE_UNSPECIFIED", "DISABLED", "ENABLED"]

@typing.type_check_only
class ServiceConfig(typing_extensions.TypedDict, total=False):
    apis: _list[Api]
    authentication: Authentication
    documentation: Documentation
    endpoints: _list[Endpoint]
    monitoredResources: _list[MonitoredResourceDescriptor]
    monitoring: Monitoring
    name: str
    quota: Quota
    title: str
    usage: Usage

@typing.type_check_only
class ServiceIdentity(typing_extensions.TypedDict, total=False):
    email: str
    uniqueId: str

@typing.type_check_only
class SourceContext(typing_extensions.TypedDict, total=False):
    fileName: str

@typing.type_check_only
class SourceInfo(typing_extensions.TypedDict, total=False):
    sourceFiles: _list[dict[str, typing.Any]]

@typing.type_check_only
class Status(typing_extensions.TypedDict, total=False):
    code: int
    details: _list[dict[str, typing.Any]]
    message: str

@typing.type_check_only
class SystemParameter(typing_extensions.TypedDict, total=False):
    httpHeader: str
    name: str
    urlQueryParameter: str

@typing.type_check_only
class SystemParameterRule(typing_extensions.TypedDict, total=False):
    parameters: _list[SystemParameter]
    selector: str

@typing.type_check_only
class SystemParameters(typing_extensions.TypedDict, total=False):
    rules: _list[SystemParameterRule]

@typing.type_check_only
class Type(typing_extensions.TypedDict, total=False):
    fields: _list[Field]
    name: str
    oneofs: _list[str]
    options: _list[Option]
    sourceContext: SourceContext
    syntax: typing_extensions.Literal["SYNTAX_PROTO2", "SYNTAX_PROTO3"]

@typing.type_check_only
class UpdateAdminQuotaPolicyMetadata(typing_extensions.TypedDict, total=False): ...

@typing.type_check_only
class Usage(typing_extensions.TypedDict, total=False):
    producerNotificationChannel: str
    requirements: _list[str]
    rules: _list[UsageRule]

@typing.type_check_only
class UsageRule(typing_extensions.TypedDict, total=False):
    allowUnregisteredCalls: bool
    selector: str
    skipServiceControl: bool



import collections.abc
import typing

import httplib2  # type: ignore
import typing_extensions

import googleapiclient.discovery
import googleapiclient.http  # type: ignore

from .schemas import *

_list = list

@typing.type_check_only
class SheetsResource(googleapiclient.discovery.Resource):
    @typing.type_check_only
    class SpreadsheetsResource(googleapiclient.discovery.Resource):
        @typing.type_check_only
        class DeveloperMetadataResource(googleapiclient.discovery.Resource):
            def get(
                self, *, spreadsheetId: str, metadataId: int, **kwargs: typing.Any
            ) -> DeveloperMetadataHttpRequest: ...
            def search(
                self,
                *,
                spreadsheetId: str,
                body: SearchDeveloperMetadataRequest = ...,
                **kwargs: typing.Any
            ) -> SearchDeveloperMetadataResponseHttpRequest: ...

        @typing.type_check_only
        class SheetsResource(googleapiclient.discovery.Resource):
            def copyTo(
                self,
                *,
                spreadsheetId: str,
                sheetId: int,
                body: CopySheetToAnotherSpreadsheetRequest = ...,
                **kwargs: typing.Any
            ) -> SheetPropertiesHttpRequest: ...

        @typing.type_check_only
        class ValuesResource(googleapiclient.discovery.Resource):
            def append(
                self,
                *,
                spreadsheetId: str,
                range: str,
                body: ValueRange = ...,
                includeValuesInResponse: bool = ...,
                insertDataOption: typing_extensions.Literal[
                    "OVERWRITE", "INSERT_ROWS"
                ] = ...,
                responseDateTimeRenderOption: typing_extensions.Literal[
                    "SERIAL_NUMBER", "FORMATTED_STRING"
                ] = ...,
                responseValueRenderOption: typing_extensions.Literal[
                    "FORMATTED_VALUE", "UNFORMATTED_VALUE", "FORMULA"
                ] = ...,
                valueInputOption: typing_extensions.Literal[
                    "INPUT_VALUE_OPTION_UNSPECIFIED", "RAW", "USER_ENTERED"
                ] = ...,
                **kwargs: typing.Any
            ) -> AppendValuesResponseHttpRequest: ...
            def batchClear(
                self,
                *,
                spreadsheetId: str,
                body: BatchClearValuesRequest = ...,
                **kwargs: typing.Any
            ) -> BatchClearValuesResponseHttpRequest: ...
            def batchClearByDataFilter(
                self,
                *,
                spreadsheetId: str,
                body: BatchClearValuesByDataFilterRequest = ...,
                **kwargs: typing.Any
            ) -> BatchClearValuesByDataFilterResponseHttpRequest: ...
            def batchGet(
                self,
                *,
                spreadsheetId: str,
                dateTimeRenderOption: typing_extensions.Literal[
                    "SERIAL_NUMBER", "FORMATTED_STRING"
                ] = ...,
                majorDimension: typing_extensions.Literal[
                    "DIMENSION_UNSPECIFIED", "ROWS", "COLUMNS"
                ] = ...,
                ranges: str | _list[str] = ...,
                valueRenderOption: typing_extensions.Literal[
                    "FORMATTED_VALUE", "UNFORMATTED_VALUE", "FORMULA"
                ] = ...,
                **kwargs: typing.Any
            ) -> BatchGetValuesResponseHttpRequest: ...
            def batchGetByDataFilter(
                self,
                *,
                spreadsheetId: str,
                body: BatchGetValuesByDataFilterRequest = ...,
                **kwargs: typing.Any
            ) -> BatchGetValuesByDataFilterResponseHttpRequest: ...
            def batchUpdate(
                self,
                *,
                spreadsheetId: str,
                body: BatchUpdateValuesRequest = ...,
                **kwargs: typing.Any
            ) -> BatchUpdateValuesResponseHttpRequest: ...
            def batchUpdateByDataFilter(
                self,
                *,
                spreadsheetId: str,
                body: BatchUpdateValuesByDataFilterRequest = ...,
                **kwargs: typing.Any
            ) -> BatchUpdateValuesByDataFilterResponseHttpRequest: ...
            def clear(
                self,
                *,
                spreadsheetId: str,
                range: str,
                body: ClearValuesRequest = ...,
                **kwargs: typing.Any
            ) -> ClearValuesResponseHttpRequest: ...
            def get(
                self,
                *,
                spreadsheetId: str,
                range: str,
                dateTimeRenderOption: typing_extensions.Literal[
                    "SERIAL_NUMBER", "FORMATTED_STRING"
                ] = ...,
                majorDimension: typing_extensions.Literal[
                    "DIMENSION_UNSPECIFIED", "ROWS", "COLUMNS"
                ] = ...,
                valueRenderOption: typing_extensions.Literal[
                    "FORMATTED_VALUE", "UNFORMATTED_VALUE", "FORMULA"
                ] = ...,
                **kwargs: typing.Any
            ) -> ValueRangeHttpRequest: ...
            def update(
                self,
                *,
                spreadsheetId: str,
                range: str,
                body: ValueRange = ...,
                includeValuesInResponse: bool = ...,
                responseDateTimeRenderOption: typing_extensions.Literal[
                    "SERIAL_NUMBER", "FORMATTED_STRING"
                ] = ...,
                responseValueRenderOption: typing_extensions.Literal[
                    "FORMATTED_VALUE", "UNFORMATTED_VALUE", "FORMULA"
                ] = ...,
                valueInputOption: typing_extensions.Literal[
                    "INPUT_VALUE_OPTION_UNSPECIFIED", "RAW", "USER_ENTERED"
                ] = ...,
                **kwargs: typing.Any
            ) -> UpdateValuesResponseHttpRequest: ...

        def batchUpdate(
            self,
            *,
            spreadsheetId: str,
            body: BatchUpdateSpreadsheetRequest = ...,
            **kwargs: typing.Any
        ) -> BatchUpdateSpreadsheetResponseHttpRequest: ...
        def create(
            self, *, body: Spreadsheet = ..., **kwargs: typing.Any
        ) -> SpreadsheetHttpRequest: ...
        def get(
            self,
            *,
            spreadsheetId: str,
            includeGridData: bool = ...,
            ranges: str | _list[str] = ...,
            **kwargs: typing.Any
        ) -> SpreadsheetHttpRequest: ...
        def getByDataFilter(
            self,
            *,
            spreadsheetId: str,
            body: GetSpreadsheetByDataFilterRequest = ...,
            **kwargs: typing.Any
        ) -> SpreadsheetHttpRequest: ...
        def developerMetadata(self) -> DeveloperMetadataResource: ...
        def sheets(self) -> SheetsResource: ...
        def values(self) -> ValuesResource: ...

    def new_batch_http_request(
        self,
        callback: collections.abc.Callable[
            [
                str,
                googleapiclient.http.HttpRequest,
                googleapiclient.errors.HttpError | None,
            ],
            typing.Any,
        ]
        | None = ...,
    ) -> googleapiclient.http.BatchHttpRequest: ...
    def spreadsheets(self) -> SpreadsheetsResource: ...

@typing.type_check_only
class AppendValuesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> AppendValuesResponse: ...

@typing.type_check_only
class BatchClearValuesByDataFilterResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchClearValuesByDataFilterResponse: ...

@typing.type_check_only
class BatchClearValuesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchClearValuesResponse: ...

@typing.type_check_only
class BatchGetValuesByDataFilterResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchGetValuesByDataFilterResponse: ...

@typing.type_check_only
class BatchGetValuesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchGetValuesResponse: ...

@typing.type_check_only
class BatchUpdateSpreadsheetResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchUpdateSpreadsheetResponse: ...

@typing.type_check_only
class BatchUpdateValuesByDataFilterResponseHttpRequest(
    googleapiclient.http.HttpRequest
):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchUpdateValuesByDataFilterResponse: ...

@typing.type_check_only
class BatchUpdateValuesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> BatchUpdateValuesResponse: ...

@typing.type_check_only
class ClearValuesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ClearValuesResponse: ...

@typing.type_check_only
class DeveloperMetadataHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> DeveloperMetadata: ...

@typing.type_check_only
class SearchDeveloperMetadataResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SearchDeveloperMetadataResponse: ...

@typing.type_check_only
class SheetPropertiesHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> SheetProperties: ...

@typing.type_check_only
class SpreadsheetHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> Spreadsheet: ...

@typing.type_check_only
class UpdateValuesResponseHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> UpdateValuesResponse: ...

@typing.type_check_only
class ValueRangeHttpRequest(googleapiclient.http.HttpRequest):
    def execute(
        self,
        http: httplib2.Http | googleapiclient.http.HttpMock | None = ...,
        num_retries: int = ...,
    ) -> ValueRange: ...
